import { toRefs, createTextVNode, createVNode, mergeProps, computed, defineComponent } from 'vue';
import '../../../../utils/index.mjs';
import '../../../../theme/index.mjs';
import { InAvatar } from '../../avatar/index.mjs';
import { avatarGroupProps } from './avatar-group.mjs';
import { useNamespace } from '../../../../utils/src/dom/use-namespace.mjs';
import { unRefs } from '../../../../utils/src/vue/composition/un-refs.mjs';
import { css, cx } from '../../../../node_modules/.pnpm/@emotion_css@11.11.2/node_modules/@emotion/css/dist/emotion-css.esm.mjs';

"use strict";
var AvatarGroup = /* @__PURE__ */ defineComponent({
  props: avatarGroupProps,
  setup(props, {
    slots,
    attrs
  }) {
    const {
      max,
      avatarBorder,
      ...avatarProps
    } = toRefs(props);
    const ns = useNamespace("avatar-group");
    const slotsVNodes = slots?.default?.() ?? [];
    let vNodes = slotsVNodes;
    if (max.value && +max.value < slotsVNodes.length) {
      const count = slotsVNodes.length - +max.value;
      vNodes = [...slotsVNodes.slice(0, +max.value), createVNode(InAvatar, null, {
        default: () => [createTextVNode("+"), count]
      })];
    }
    const renderVNodes = computed(() => {
      return vNodes.map((VNode) => createVNode(VNode, mergeProps(unRefs(avatarProps), VNode.props ?? {}), null));
    });
    const classList = computed(() => {
      const classes = attrs?.class?.split(" ") ?? [];
      classes.push(ns.b());
      classes.push(css`
        & .in-avatar {
          border: 2px solid ${avatarBorder.value};
        }
      `);
      return cx(classes);
    });
    return () => createVNode("div", mergeProps(attrs, {
      class: classList.value
    }), [renderVNodes.value.reverse()]);
  }
});

export { AvatarGroup as default };
//# sourceMappingURL=index.mjs.map
