import { useSlots, computed, openBlock, unref, normalizeClass, renderSlot, Fragment, toDisplayString, createTextVNode, createElementBlock, createCommentVNode, withCtx, createBlock, defineComponent } from 'vue';
import '../../../../utils/index.mjs';
import '../../../../theme/index.mjs';
import { InTypography } from '../../typography/index.mjs';
import { badgeProps } from './badge.mjs';
import { useNamespace } from '../../../../utils/src/dom/use-namespace.mjs';
import { useColor } from '../../../../theme/src/hooks/use-color.mjs';
import { css } from '../../../../node_modules/.pnpm/@emotion_css@11.11.2/node_modules/@emotion/css/dist/emotion-css.esm.mjs';
import { styled } from '../../../../theme/src/core/styled.mjs';
import { debugWarn } from '../../../../utils/src/javascript/error.mjs';

"use strict";
var _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "index",
  props: badgeProps,
  setup(__props) {
    const props = __props;
    const slots = useSlots();
    const ns = useNamespace("badge");
    const [$color, $onColor] = useColor(props, "color");
    const translate = {
      top: "-50%",
      bottom: "50%",
      right: "50%",
      left: "-50%"
    };
    const positionCss = computed(
      () => slots.default ? css`
        ${props.xAlign}: 0;
        ${props.yAlign}: 0;
        position: absolute;
        transform: scale(1)
          translate(
            ${props.overlap ? "0%" : translate[props.xAlign]},
            ${props.overlap ? "0%" : translate[props.yAlign]}
          );
      ` : ""
    );
    const BadgeTypography = computed(
      () => styled(InTypography, { color: $onColor.value })`
    background-color: ${$color.value};
    height: ${props.variant === "dot" ? "8px" : "20px"};
    min-width: ${props.variant === "dot" ? "8px" : "20px"};
    border-radius: 10px;
    padding: ${props.variant === "dot" ? "0" : "6px"} !important;
  `
    );
    const showTypography = computed(() => {
      const { content, variant } = props;
      return variant === "dot" || ["string", "number"].includes(typeof content);
    });
    const badgeContent = computed(() => {
      const { content, max } = props;
      if (!showTypography.value) {
        return null;
      }
      if (content && max) {
        if (!["string", "number"].includes(typeof content)) {
          debugWarn(
            "[Interface UI]",
            'props.content can only be "string" or "number" when set props.max'
          );
          return null;
        }
        return max ? +max < +content ? `${max}+` : content : content;
      }
      return content;
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(
        "span",
        {
          class: normalizeClass(unref(ns).b())
        },
        [
          renderSlot(_ctx.$slots, "default"),
          showTypography.value ? (openBlock(), createBlock(unref(BadgeTypography), {
            key: 0,
            class: normalizeClass([unref(ns).m("icon"), positionCss.value]),
            variant: "label.small"
          }, {
            default: withCtx(() => [
              props.variant !== "dot" ? (openBlock(), createElementBlock(
                Fragment,
                { key: 0 },
                [
                  createTextVNode(
                    toDisplayString(badgeContent.value),
                    1
                    /* TEXT */
                  )
                ],
                64
                /* STABLE_FRAGMENT */
              )) : createCommentVNode("v-if", true)
            ]),
            _: 1
            /* STABLE */
          }, 8, ["class"])) : (openBlock(), createBlock(props.content, {
            key: 1,
            class: normalizeClass([unref(ns).m("icon"), positionCss.value])
          }, null, 8, ["class"]))
        ],
        2
        /* CLASS */
      );
    };
  }
});

export { _sfc_main as default };
//# sourceMappingURL=index.vue2.mjs.map
