import { computed, ref, mergeProps, createVNode, Fragment, defineComponent } from 'vue';
import '../../../../utils/index.mjs';
import { InButtonBase } from '../../button-base/index.mjs';
import MoreHorizFilled from '../../svg-icon/internal/MoreHorizFilled.vue.mjs';
import { breadcrumbProps } from './breadcrumb.mjs';
import useCss from './index.jss.mjs';
import { useNamespace } from '../../../../utils/src/dom/use-namespace.mjs';

"use strict";
var Breadcrumb = /* @__PURE__ */ defineComponent({
  props: breadcrumbProps,
  setup(props, {
    slots
  }) {
    const ns = useNamespace("breadcrumb");
    const slotsCount = computed(() => slots.default?.().length ?? 0);
    const cssClass = useCss(props);
    const showAllSlots = ref(!!props.max && +props.max < slotsCount.value);
    const slotsVNodes = computed(() => (slots.default?.() ?? []).map((VNode) => createVNode(VNode, mergeProps({
      underline: props.underline,
      color: "inherit",
      cs: {
        "--in-link-color-rgb": "var(--in-breadcrumb-color-rgb)"
      }
    }, VNode.props), null)));
    const separator = (() => {
      const Separator = props.separator;
      return createVNode("li", {
        "class": [ns.m("separator")]
      }, [typeof Separator === "string" ? Separator : createVNode(Separator, {
        "size": 20
      }, null)]);
    })();
    const renderSlotsWithoutMaxLimit = () => slotsVNodes.value.map((VNode, index) => createVNode(Fragment, null, [createVNode("li", {
      "class": [ns.m("item")]
    }, [createVNode(VNode, null, null)]), index !== slotsCount.value - 1 && separator]));
    const renderSlotsWithMaxLimit = () => {
      const VNodes = [];
      if (!props.max) {
        return VNodes;
      }
      for (let i = 0; i < +props.max - 1; i++) {
        const VNode = slotsVNodes.value?.[i];
        VNodes.push(createVNode(Fragment, null, [createVNode("li", {
          "class": [ns.m("item")]
        }, [createVNode(VNode, null, null)]), separator]));
      }
      const ButtonBase = InButtonBase;
      const MoreButton = createVNode(ButtonBase, {
        "class": [ns.em("button", "more")],
        "onClick": () => showAllSlots.value = !showAllSlots.value
      }, {
        default: () => [createVNode(MoreHorizFilled, null, null)]
      });
      const LastVNode = slotsVNodes.value?.[slotsCount.value - 1];
      VNodes.push(createVNode("li", null, [createVNode(MoreButton, null, null)]), separator, createVNode("li", {
        "class": [ns.m("item")]
      }, [createVNode(LastVNode, null, null)]));
      return VNodes;
    };
    return () => createVNode("nav", {
      "class": [ns.b(), cssClass.value]
    }, [createVNode("ol", {
      "class": [ns.m("container")]
    }, [showAllSlots.value ? renderSlotsWithMaxLimit() : renderSlotsWithoutMaxLimit()])]);
  }
});

export { Breadcrumb as default };
//# sourceMappingURL=index.mjs.map
