import { toRefs, computed, mergeProps, createVNode, defineComponent } from 'vue';
import '../../../../utils/index.mjs';
import '../../../../theme/index.mjs';
import { buttonGroupProps } from './button-group.mjs';
import { useNamespace } from '../../../../utils/src/dom/use-namespace.mjs';
import { useColor } from '../../../../theme/src/hooks/use-color.mjs';
import { useRgbColor } from '../../../../theme/src/hooks/use-rgb-color.mjs';
import { css, cx } from '../../../../node_modules/.pnpm/@emotion_css@11.11.2/node_modules/@emotion/css/dist/emotion-css.esm.mjs';
import { unRefs } from '../../../../utils/src/vue/composition/un-refs.mjs';

"use strict";
var ButtonGroup = /* @__PURE__ */ defineComponent({
  props: buttonGroupProps,
  setup(props, {
    slots,
    attrs
  }) {
    const ns = useNamespace("button-group");
    const {
      orientation,
      ...buttonProps
    } = toRefs(props);
    const [$color] = useColor(props, "color");
    const [$colorRgb] = useRgbColor(props, "color");
    const cssClass = computed(() => css`
        --in-button-group-color: ${$color.value};
        --in-button-group-color-rgb: ${$colorRgb.value};
      `);
    const classList = computed(() => {
      const {
        variant,
        shape,
        size
      } = unRefs(buttonProps);
      return cx([ns.b(), ns.m(size), ns.m(shape), ns.m(variant), ns.m(orientation.value), cssClass.value]);
    });
    const slotsVNodes = (slots?.default?.() ?? []).map((VNode) => createVNode(VNode, mergeProps(unRefs(buttonProps), attrs, VNode.props ?? {}), null));
    return () => createVNode("div", {
      "class": classList.value
    }, [slotsVNodes]);
  }
});

export { ButtonGroup as default };
//# sourceMappingURL=index.mjs.map
