import { openBlock, Transition, unref, toHandlers, mergeProps, renderSlot, withCtx, createBlock, defineComponent } from 'vue';
import '../../../../utils/index.mjs';
import { collapseProps } from './collapse.mjs';
import { useNamespace } from '../../../../utils/src/dom/use-namespace.mjs';

"use strict";
var _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "index",
  props: collapseProps,
  setup(__props) {
    const props = __props;
    const ns = useNamespace("collapse");
    const dataset = props.orientation === "vertical" ? {
      oldPaddingTop: "",
      oldPaddingBottom: "",
      oldOverflow: ""
    } : {
      oldPaddingLeft: "",
      oldPaddingRight: "",
      oldOverflow: ""
    };
    const reset = (el) => {
      if (props.orientation === "vertical") {
        el.style.maxHeight = "";
        el.style.overflow = dataset.oldOverflow;
        el.style.paddingTop = dataset.oldPaddingTop;
        el.style.paddingBottom = dataset.oldPaddingBottom;
      } else {
        el.style.maxWidth = "";
        el.style.overflow = dataset.oldOverflow;
        el.style.paddingLeft = dataset.oldPaddingLeft;
        el.style.paddingRight = dataset.oldPaddingRight;
      }
    };
    const listener = {
      beforeEnter(el) {
        if (props.orientation === "vertical") {
          dataset.oldPaddingTop = el.style.paddingTop;
          dataset.oldPaddingBottom = el.style.paddingBottom;
          el.style.maxHeight = 0;
          el.style.paddingTop = 0;
          el.style.paddingBottom = 0;
        } else {
          dataset.oldPaddingLeft = el.style.paddingLeft;
          dataset.oldPaddingRight = el.style.paddingRight;
          el.style.maxWidth = 0;
          el.style.paddingLeft = 0;
          el.style.paddingRight = 0;
        }
      },
      enter(el) {
        dataset.oldOverflow = el.style.overflow;
        if (props.orientation === "vertical") {
          if (el.scrollHeight !== 0) {
            el.style.maxHeight = `${el.scrollHeight}px`;
          } else {
            el.style.maxHeight = 0;
          }
          el.style.paddingTop = dataset.oldPaddingTop;
          el.style.paddingBottom = dataset.oldPaddingBottom;
        } else {
          if (el.scrollWidth !== 0) {
            el.style.maxWidth = `${el.scrollWidth}px`;
          } else {
            el.style.maxWidth = 0;
          }
          el.style.paddingLeft = dataset.oldPaddingLeft;
          el.style.paddingRight = dataset.oldPaddingRight;
        }
      },
      afterEnter(el) {
        if (props.orientation === "vertical") {
          el.style.maxHeight = "";
          el.style.overflow = dataset.oldOverflow;
        } else {
          el.style.maxWidth = "";
          el.style.overflow = dataset.oldOverflow;
        }
      },
      enterCancelled(el) {
        reset(el);
      },
      beforeLeave(el) {
        if (props.orientation === "vertical") {
          dataset.oldPaddingTop = el.style.paddingTop;
          dataset.oldPaddingBottom = el.style.paddingBottom;
          dataset.oldOverflow = el.style.overflow;
          el.style.maxHeight = `${el.scrollHeight}px`;
        } else {
          dataset.oldPaddingLeft = el.style.paddingLeft;
          dataset.oldPaddingRight = el.style.paddingRight;
          dataset.oldOverflow = el.style.overflow;
          el.style.maxWidth = `${el.scrollWidth}px`;
        }
      },
      leave(el) {
        if (props.orientation === "vertical") {
          if (el.scrollHeight !== 0) {
            el.style.maxHeight = 0;
            el.style.paddingTop = 0;
            el.style.paddingBottom = 0;
          }
        } else {
          if (el.scrollWidth !== 0) {
            el.style.maxWidth = 0;
            el.style.paddingLeft = 0;
            el.style.paddingRight = 0;
          }
        }
      },
      afterLeave(el) {
        reset(el);
      },
      leaveCancelled(el) {
        reset(el);
      }
    };
    return (_ctx, _cache) => {
      return openBlock(), createBlock(Transition, mergeProps({
        name: unref(ns).b()
      }, toHandlers(listener)), {
        default: withCtx(() => [
          renderSlot(_ctx.$slots, "default")
        ]),
        _: 3
        /* FORWARDED */
      }, 16, ["name"]);
    };
  }
});

export { _sfc_main as default };
//# sourceMappingURL=index.vue2.mjs.map
