import { ref, onBeforeUnmount, nextTick, watch, openBlock, unref, withModifiers, mergeProps, renderSlot, createElementVNode, withCtx, createBlock, defineComponent } from 'vue';
import '../../../../utils/index.mjs';
import { InModal } from '../../modal/index.mjs';
import { popoverProps } from './popover.mjs';
import useCss from './index.jss.mjs';
import { useNamespace } from '../../../../utils/src/dom/use-namespace.mjs';
import { throttle, off, on } from '../../../../utils/src/javascript/helpers.mjs';

"use strict";
var _sfc_main = /* @__PURE__ */ defineComponent({
  ...{ inheritAttrs: false },
  __name: "index",
  props: popoverProps,
  emits: ["update:modelValue", "close"],
  setup(__props) {
    const props = __props;
    const ns = useNamespace("popover");
    const popoverRef = ref(null);
    const style = ref({
      top: "0",
      left: "0",
      transformOrigin: "top left",
      minWidth: "0"
    });
    const cssClass = useCss(props);
    const DEFAULT_PLACEMENT = { x: "left", y: "bottom" };
    const calculateStyleFromAnchor = (anchor) => {
      if (!popoverRef.value) {
        return;
      }
      if (!props.anchor) {
        return;
      }
      const { placement } = props;
      let { x, y } = { ...DEFAULT_PLACEMENT, ...placement };
      const { top, left, width, height } = anchor.getBoundingClientRect();
      const popoverWidth = Math.max(popoverRef.value.offsetWidth, width);
      const popoverHeight = popoverRef.value.offsetHeight;
      const { innerWidth, innerHeight } = window;
      if (x === "left") {
        if (innerWidth - left < popoverWidth) {
          x = "right";
        }
      } else if (x === "right") {
        if (left + width < popoverWidth) {
          x = "left";
        }
      } else {
        if (left + width / 2 < popoverWidth / 2) {
          x = "right";
        } else if (innerWidth - left - width / 2 < popoverWidth / 2) {
          x = "left";
        }
      }
      if (y === "top") {
        if (top < popoverHeight) {
          y = "bottom";
        }
      } else {
        if (innerHeight - top - height < popoverHeight) {
          y = "top";
        }
      }
      const position = { top: 0, left: 0 };
      if (x === "left") {
        position.left = left;
      } else if (x === "right") {
        position.left = left + width - popoverWidth;
      } else {
        position.left = left + width / 2 - popoverWidth / 2;
      }
      if (y === "top") {
        position.top = top - popoverHeight;
      } else {
        position.top = top + height;
      }
      style.value = {
        top: `${position.top}px`,
        left: `${position.left}px`,
        transformOrigin: `${x} ${y === "top" ? "bottom" : "top"}`,
        minWidth: `${width}px`
      };
    };
    const calculateStyleFromEvent = (e) => {
      if (!popoverRef.value) {
        return;
      }
      const { placement } = props;
      let { x, y } = { ...DEFAULT_PLACEMENT, ...placement };
      const { x: left, y: top } = e;
      const popoverWidth = popoverRef.value.offsetWidth;
      const popoverHeight = popoverRef.value.offsetHeight;
      const { innerWidth, innerHeight } = window;
      if (x === "center") {
        x = "right";
      }
      if (x === "left") {
        if (left < popoverWidth) {
          x = "right";
        }
      } else {
        if (innerWidth - left < popoverWidth) {
          x = "left";
        }
      }
      if (y === "top") {
        if (top < popoverHeight) {
          y = "bottom";
        }
      } else {
        if (innerHeight - top < popoverHeight) {
          y = "top";
        }
      }
      const position = { top: 0, left: 0 };
      if (x === "left") {
        position.left = left - popoverWidth;
      } else {
        position.left = left;
      }
      if (y === "top") {
        position.top = top - popoverHeight;
      } else {
        position.top = top;
      }
      style.value = {
        top: `${position.top}px`,
        left: `${position.left}px`,
        transformOrigin: `${x === "left" ? "right" : "left"} ${y === "top" ? "bottom" : "top"}`,
        minWidth: `${popoverWidth}px`
      };
    };
    const pageChange = throttle(() => {
      calculateStyleFromAnchor(props.anchor);
    }, 10);
    onBeforeUnmount(() => {
      off(window, "scroll", pageChange);
      off(window, "resize", pageChange);
    });
    watch(
      () => props.open,
      (newVal) => {
        if (newVal) {
          nextTick(() => {
            on(window, "scroll", pageChange);
            on(window, "resize", pageChange);
            props.anchor instanceof HTMLElement ? calculateStyleFromAnchor(props.anchor) : calculateStyleFromEvent(props.anchor);
          });
        } else {
          off(window, "scroll", pageChange);
          off(window, "resize", pageChange);
        }
      }
    );
    return (_ctx, _cache) => {
      return openBlock(), createBlock(unref(InModal), {
        "keep-mounted": _ctx.$props.keepMounted,
        "model-value": _ctx.$props.open,
        backdrop: _ctx.$props.backdrop,
        onClick: _cache[1] || (_cache[1] = ($event) => _ctx.$emit("close"))
      }, {
        default: withCtx(() => [
          createElementVNode(
            "div",
            mergeProps({
              ref_key: "popoverRef",
              ref: popoverRef
            }, _ctx.$attrs, {
              class: [unref(ns).b(), _ctx.$props.open ? unref(ns).m("open") : unref(ns).m("close"), unref(cssClass)],
              style: style.value,
              onClick: _cache[0] || (_cache[0] = withModifiers(() => {
              }, ["stop"]))
            }),
            [
              renderSlot(_ctx.$slots, "default")
            ],
            16
            /* FULL_PROPS */
          )
        ]),
        _: 3
        /* FORWARDED */
      }, 8, ["keep-mounted", "model-value", "backdrop"]);
    };
  }
});

export { _sfc_main as default };
//# sourceMappingURL=index.vue2.mjs.map
