import { reactive, getCurrentInstance, watchEffect, onMounted, onUnmounted, openBlock, unref, normalizeClass, Fragment, normalizeStyle, createElementBlock, renderList, defineComponent } from 'vue';
import '../../../../utils/index.mjs';
import '../../../../theme/index.mjs';
import { rippleProps } from './ripple.mjs';
import { useNamespace } from '../../../../utils/src/dom/use-namespace.mjs';
import { useColor } from '../../../../theme/src/hooks/use-color.mjs';
import { addUnit } from '../../../../utils/src/dom/style.mjs';

"use strict";
var _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "index",
  props: rippleProps,
  setup(__props, { expose: __expose }) {
    const props = __props;
    const ripplesArr = reactive([]);
    const parent = getCurrentInstance()?.parent;
    const ns = useNamespace("ripple");
    let bounce = null;
    let listener = null;
    const $color = useColor(props, "color")[0].value;
    const addRipple = (event) => {
      const target = event.currentTarget;
      const rect = target.getBoundingClientRect();
      const size = Math.max(target.clientWidth, target.clientHeight);
      const radius = size / 2;
      const x = props.center ? target.clientWidth / 2 - radius : event.clientX - rect.left - radius;
      const y = props.center ? target.clientHeight / 2 - radius : event.clientY - rect.top - radius;
      ripplesArr.push({ x, y, size });
    };
    const clear = () => {
      if (bounce) {
        clearTimeout(bounce);
        bounce = null;
      }
    };
    watchEffect(() => {
      if (ripplesArr.length > 0) {
        clear();
        bounce = setTimeout(() => {
          ripplesArr.length = 0;
          clear();
        }, props.duration * 2);
      }
    });
    onMounted(() => {
      if (parent) {
        listener = parent.proxy?.$el.addEventListener("mousedown", addRipple);
      }
    });
    onUnmounted(() => {
      clear();
      if (listener) {
        parent?.proxy?.$el.removeEventListener(listener);
        listener = null;
      }
    });
    __expose({ addRipple });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(
        "span",
        {
          class: normalizeClass([unref(ns).b()])
        },
        [
          (openBlock(true), createElementBlock(
            Fragment,
            null,
            renderList(ripplesArr, (ripple, index) => {
              return openBlock(), createElementBlock(
                "span",
                {
                  key: `ripple_${index}`,
                  style: normalizeStyle({
                    top: unref(addUnit)(ripple.y),
                    left: unref(addUnit)(ripple.x),
                    width: unref(addUnit)(ripple.size),
                    height: unref(addUnit)(ripple.size),
                    background: unref($color),
                    animationDuration: `${_ctx.$props.duration}ms`
                  }),
                  class: normalizeClass([[unref(ns).e("span")], "pressed-state-layer"])
                },
                null,
                6
                /* CLASS, STYLE */
              );
            }),
            128
            /* KEYED_FRAGMENT */
          ))
        ],
        2
        /* CLASS */
      );
    };
  }
});

export { _sfc_main as default };
//# sourceMappingURL=index.vue2.mjs.map
