import { computed } from 'vue';
import '../../../../theme/index.mjs';
import { useTheme } from '../../../../theme/src/hooks/use-theme.mjs';
import { useColor } from '../../../../theme/src/hooks/use-color.mjs';
import { css, cx } from '../../../../node_modules/.pnpm/@emotion_css@11.11.2/node_modules/@emotion/css/dist/emotion-css.esm.mjs';

"use strict";
const useCss = (props) => computed(() => {
  const {
    typography: { pxToRem }
  } = useTheme().value;
  const [$color] = useColor(props, "color");
  const [$fill] = useColor(props, "fill");
  let fontSize;
  const _size = +props.size;
  if (isNaN(_size)) {
    const [_, size, unit] = /(d+)(w+)/.exec(props.size) || [];
    fontSize = unit === "px" ? pxToRem(+size) : props.size;
  } else {
    fontSize = pxToRem(_size);
  }
  const styleFromCs = props.cs ? css(props.cs) : "";
  return cx(
    css([
      {
        userSelect: "none",
        width: "1em",
        height: "1em",
        display: "inline-block",
        flexShrink: 0,
        transition: "fill 200ms cubic-bezier(0.4, 0, 0.2, 1) 0ms",
        fontSize,
        color: $color.value
      },
      props.fill && {
        fill: $fill.value
      }
    ]),
    styleFromCs
  );
});

export { useCss as default };
//# sourceMappingURL=index.jss.mjs.map
