import { useAttrs, useSlots, computed, openBlock, unref, normalizeClass, toDisplayString, createTextVNode, withCtx, createBlock, createCommentVNode, guardReactiveProps, normalizeProps, renderSlot, mergeProps, createVNode, createElementBlock, createElementVNode, defineComponent } from 'vue';
import '../../../../utils/index.mjs';
import '../../../../constants/index.mjs';
import { InTypography } from '../../typography/index.mjs';
import { InInputBase } from '../../input-base/index.mjs';
import { textFieldProps } from './text-field.mjs';
import useCss from './index.jss.mjs';
import { useNamespace } from '../../../../utils/src/dom/use-namespace.mjs';
import { UPDATE_MODEL_EVENT } from '../../../../constants/src/events.mjs';
import { generateId } from '../../../../utils/src/dom/id.mjs';
import { isEmpty } from '../../../../utils/src/javascript/check.mjs';

"use strict";
var _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "index",
  props: textFieldProps,
  emits: ["update:modelValue"],
  setup(__props, { emit: __emit }) {
    const props = __props;
    const emit = __emit;
    const attrs = useAttrs();
    const slots = useSlots();
    const ns = useNamespace("text-field");
    const cssClass = useCss(props);
    const value = computed({
      get() {
        return props.modelValue;
      },
      set(newVal) {
        emit(UPDATE_MODEL_EVENT, newVal);
      }
    });
    const id = attrs?.id ? attrs.id : `text-field-${generateId()}`;
    const label = computed(() => props?.label ?? "");
    const hasContent = computed(() => {
      const startAdornment = slots?.startAdornment?.();
      return !isEmpty(props.modelValue) || !!startAdornment;
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(
        "div",
        {
          class: normalizeClass([
            unref(ns).b(),
            unref(ns).m(_ctx.$props.variant),
            unref(ns).m(_ctx.$props.size),
            _ctx.$props.error ? unref(ns).m("error") : "",
            hasContent.value ? unref(ns).m("content-within") : "",
            unref(cssClass)
          ])
        },
        [
          _ctx.$props?.label ? (openBlock(), createBlock(unref(InTypography), {
            key: 0,
            id: unref(id),
            component: "label",
            class: normalizeClass([unref(ns).e("label")]),
            color: "rgb(var(--md-sys-color-on-surface-rgb) / 0.6);",
            "no-warp": ""
          }, {
            default: withCtx(() => [
              createTextVNode(
                toDisplayString(label.value),
                1
                /* TEXT */
              )
            ]),
            _: 1
            /* STABLE */
          }, 8, ["id", "class"])) : createCommentVNode("v-if", true),
          createElementVNode(
            "div",
            {
              class: normalizeClass([unref(ns).m("input-wrapper")])
            },
            [
              renderSlot(_ctx.$slots, "startAdornment", normalizeProps(guardReactiveProps({ class: [unref(ns).m("start-adornment")] }))),
              createVNode(unref(InInputBase), mergeProps({ id: unref(id) }, _ctx.$attrs, {
                modelValue: value.value,
                "onUpdate:modelValue": _cache[0] || (_cache[0] = ($event) => value.value = $event),
                class: [unref(ns).e("input")]
              }), null, 16, ["id", "modelValue", "class"]),
              renderSlot(_ctx.$slots, "endAdornment", normalizeProps(guardReactiveProps({ class: [unref(ns).m("end-adornment")] }))),
              _ctx.$props.variant === "outlined" && _ctx.$props?.label ? (openBlock(), createElementBlock(
                "fieldset",
                {
                  key: 0,
                  class: normalizeClass([unref(ns).m("border")])
                },
                [
                  createVNode(unref(InTypography), {
                    component: "legend",
                    "no-warp": ""
                  }, {
                    default: withCtx(() => [
                      createTextVNode(
                        toDisplayString(label.value),
                        1
                        /* TEXT */
                      )
                    ]),
                    _: 1
                    /* STABLE */
                  })
                ],
                2
                /* CLASS */
              )) : (openBlock(), createElementBlock(
                "span",
                {
                  key: 1,
                  class: normalizeClass([unref(ns).m("border")])
                },
                null,
                2
                /* CLASS */
              ))
            ],
            2
            /* CLASS */
          ),
          _ctx.$props?.supportingText ? (openBlock(), createBlock(unref(InTypography), {
            key: 1,
            class: normalizeClass([unref(ns).m("supporting-text")]),
            variant: "body.small",
            "no-warp": ""
          }, {
            default: withCtx(() => [
              createTextVNode(
                toDisplayString(_ctx.$props.supportingText),
                1
                /* TEXT */
              )
            ]),
            _: 1
            /* STABLE */
          }, 8, ["class"])) : createCommentVNode("v-if", true)
        ],
        2
        /* CLASS */
      );
    };
  }
});

export { _sfc_main as default };
//# sourceMappingURL=index.vue2.mjs.map
