import Symbol from './_Symbol.mjs';
import isArguments from './isArguments.mjs';
import isArray from './isArray.mjs';

/** Built-in value references. */
var spreadableSymbol = Symbol ? Symbol.isConcatSpreadable : undefined;

/**
 * Checks if `value` is a flattenable `arguments` object or array.
 *
 * @private
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is flattenable, else `false`.
 */
function isFlattenable(value) {
  return isArray(value) || isArguments(value) ||
    !!(spreadableSymbol && value && value[spreadableSymbol]);
}

export { isFlattenable as default };
//# sourceMappingURL=_isFlattenable.mjs.map
