import { ref, watch, createVNode, defineComponent } from 'vue';
import '../core/index.mjs';
import { injectJSS } from '../core/utils.mjs';
import '../hooks/index.mjs';
import { useTheme } from '../hooks/use-theme.mjs';
import Theme from '../core/theme.mjs';
import { useThemeProvider } from '../hooks/use-theme-provider.mjs';

"use strict";
var ThemeProvider = /* @__PURE__ */ defineComponent({
  name: "ThemeProvider",
  props: {
    theme: {
      type: Object,
      required: true
    },
    component: {
      type: [String, Object],
      default: "div"
    },
    watcher: {
      type: Function
    }
  },
  emits: ["update:theme"],
  setup(props, {
    slots,
    emit
  }) {
    const html = document.documentElement;
    const theme = ref(props.theme);
    const parentTheme = props.theme.target === "host" ? useTheme() : ref(null);
    const element = ref(null);
    const lightSchemes = theme.value._lightSchemes;
    const darkSchemes = theme.value._darkSchemes;
    const injectCss = injectJSS(theme.value.target, lightSchemes, darkSchemes, theme.value);
    const toggleTheme = (mode) => {
      const dom = props.theme.target === "root" ? html : element.value;
      const {
        schemes
      } = mode === "dark" ? darkSchemes : lightSchemes;
      if (mode === "dark") {
        dom.setAttribute("data-theme", "dark");
      } else {
        dom.removeAttribute("data-theme");
      }
      const {
        palettes,
        target,
        schemes: $schemes
      } = theme.value;
      theme.value = new Theme({
        ...$schemes,
        ...schemes
      }, palettes, mode, lightSchemes, darkSchemes, target);
      emit("update:theme", theme.value);
    };
    const watchTarget = props.theme.target === "root" ? () => props.theme.mode : () => parentTheme.value?.mode ?? props.theme.mode;
    props.watcher ? props.watcher() : watch(watchTarget, toggleTheme);
    useThemeProvider(theme);
    const Comp = props.component;
    return () => (
      // eslint-disable-next-line multiline-ternary
      theme.value.target === "root" ? slots.default?.() : createVNode(Comp, {
        "ref": element,
        "class": injectCss
      }, {
        default: () => [slots.default?.()]
      })
    );
  }
});

export { ThemeProvider as default };
//# sourceMappingURL=theme-provider.mjs.map
