import { ref } from 'vue';
import '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/index.mjs';
import Theme from './theme.mjs';
import defaultTheme from './default.theme.mjs';
import { parsePalettes, createCustomPalettes, newSchemes, parseShcemes, parsedNewSchemes, parseCustomSchemes, mergeParsedSchemes } from './utils.mjs';
import { argbFromHex } from '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/utils/string_utils.mjs';
import { themeFromSourceColor } from '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/utils/theme_utils.mjs';

"use strict";
const createTheme = (source = defaultTheme.source, options = { target: "root" }) => {
  const config = options.config ?? {};
  const target = options.target;
  const { schemes: $schemes, mode } = config;
  const customColors = [
    ...defaultTheme.customColors,
    ...config.customColors ?? []
  ];
  const dynamicTheme = themeFromSourceColor(argbFromHex(source), customColors);
  const palettes = {
    ...parsePalettes(dynamicTheme.palettes),
    ...createCustomPalettes(customColors)
  };
  const additionalSchemes = newSchemes(dynamicTheme);
  const lightSchemes = mergeParsedSchemes(
    parseShcemes(dynamicTheme.schemes.light),
    parsedNewSchemes(additionalSchemes.light),
    parseCustomSchemes(dynamicTheme.customColors, "light")
  );
  const darkSchemes = mergeParsedSchemes(
    parseShcemes(dynamicTheme.schemes.dark),
    parsedNewSchemes(additionalSchemes.dark),
    parseCustomSchemes(dynamicTheme.customColors, "dark")
  );
  const { schemes } = mode === "dark" ? darkSchemes : lightSchemes;
  const theme = ref(
    new Theme(
      { ...schemes, ...$schemes },
      palettes,
      mode,
      lightSchemes,
      darkSchemes,
      target
    )
  );
  return theme;
};

export { createTheme, createTheme as default };
//# sourceMappingURL=create-theme.mjs.map
