import { computed, ref } from 'vue';
import '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/index.mjs';
import '../../../utils/index.mjs';
import { useTheme } from './use-theme.mjs';
import { toCapitalize } from '../../../utils/src/javascript/string.mjs';
import { argbFromHex, hexFromArgb } from '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/utils/string_utils.mjs';
import { CorePalette } from '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/palettes/core_palette.mjs';

"use strict";
const genColor = (props, key, theme) => {
  return computed(() => {
    const color = props?.[key];
    if (typeof color === "function") {
      return color(theme.value);
    }
    if (color in theme.value.schemes) {
      const _color = color.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
      return `var(--md-sys-color-${_color})`;
    }
    return color;
  });
};
const genOnColor = (props, key, theme) => {
  return computed(() => {
    const color = props?.[key];
    let computedColor;
    if (typeof color === "function") {
      computedColor = color(theme.value);
    } else if (color in theme.value.schemes) {
      const _color = color.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
      if (color.startsWith("on")) {
        return `var(--md-sys-color-${_color})`;
      }
      if (`on${toCapitalize(color)}` in theme.value.schemes) {
        return `var(--md-sys-color-on-${_color})`;
      }
      computedColor = theme.value.schemes[color];
    } else if (color.startsWith("#")) {
      computedColor = color;
    } else {
      return "var(--md-sys-color-on-surface)";
    }
    const tones = CorePalette.of(argbFromHex(computedColor)).a1;
    const onColor = theme.value.mode === "dark" ? tones.tone(20) : tones.tone(100);
    return hexFromArgb(onColor);
  });
};
const useColor = (props, key) => {
  const theme = useTheme();
  if (!key || !(key in props) || !["string", "function"].includes(typeof props[key])) {
    return [ref(null), ref(null)];
  }
  const color = genColor(props, key, theme);
  const onColor = genOnColor(props, key, theme);
  return [color, onColor];
};

export { useColor };
//# sourceMappingURL=use-color.mjs.map
