import { computed, ref } from 'vue';
import '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/index.mjs';
import '../../../utils/index.mjs';
import { useTheme } from './use-theme.mjs';
import { argbFromHex } from '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/utils/string_utils.mjs';
import { rgbaFromArgb } from '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/utils/color_utils.mjs';
import { toCapitalize } from '../../../utils/src/javascript/string.mjs';
import { CorePalette } from '../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/palettes/core_palette.mjs';

"use strict";
const rgbaFromHex = (hex) => {
  if (!hex.startsWith("#")) {
    throw new Error("The color must be the hex color");
  }
  return rgbaFromArgb(argbFromHex(hex));
};
const genRgbColor = (props, key, theme) => {
  return computed(() => {
    const color = props?.[key];
    if (typeof color === "function") {
      const { r: r2, g: g2, b: b2 } = rgbaFromHex(color(theme.value));
      return `${r2} ${g2} ${b2}`;
    }
    if (color in theme.value.schemes) {
      const _color = color.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
      return `var(--md-sys-color-${_color}-rgb)`;
    } else if (!color.startsWith("#")) {
      return color;
    }
    const { r, g, b } = rgbaFromHex(color);
    return `${r} ${g} ${b}`;
  });
};
const genOnRgbColor = (props, key, theme) => {
  return computed(() => {
    const color = props?.[key];
    let computedColor;
    if (typeof color === "function") {
      computedColor = color(theme.value);
    } else if (color in theme.value.schemes) {
      const _color = color.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
      if (color.startsWith("on")) {
        return `var(--md-sys-color-${_color}-rgb)`;
      }
      if (`on${toCapitalize(color)}` in theme.value.schemes) {
        return `var(--md-sys-color-on-${_color}-rgb)`;
      }
      computedColor = theme.value.schemes[color];
    } else if (color.startsWith("#")) {
      computedColor = color;
    } else {
      return "var(--md-sys-color-on-surface-rgb)";
    }
    const tones = CorePalette.of(argbFromHex(computedColor)).a1;
    const onColor = theme.value.mode === "dark" ? tones.tone(20) : tones.tone(100);
    const { r, g, b } = rgbaFromArgb(onColor);
    return `${r} ${g} ${b}`;
  });
};
const useRgbColor = (props, key) => {
  const theme = useTheme();
  if (!key || !(key in props) || !["string", "function"].includes(typeof props[key])) {
    return [ref(null), ref(null)];
  }
  const rgbColor = genRgbColor(props, key, theme);
  const onRgbColor = genOnRgbColor(props, key, theme);
  return [rgbColor, onRgbColor];
};

export { rgbaFromHex, useRgbColor };
//# sourceMappingURL=use-rgb-color.mjs.map
