"use strict";
function debounce(func, delay) {
  let timeoutId;
  return function(...args) {
    clearTimeout(timeoutId);
    timeoutId = setTimeout(() => {
      func.apply(this, args);
    }, delay);
  };
}
function throttle(func, delay) {
  let lastCallTime = 0;
  return function(...args) {
    const currentTime = (/* @__PURE__ */ new Date()).getTime();
    if (currentTime - lastCallTime >= delay) {
      func.apply(this, args);
      lastCallTime = currentTime;
    }
  };
}
function on(element, event, handler, useCapture = false) {
  if (element && event && handler)
    element.addEventListener(event, handler, useCapture);
}
function off(element, event, handler, useCapture = false) {
  if (element && event && handler)
    element.removeEventListener(event, handler, useCapture);
}

export { debounce, off, on, throttle };
//# sourceMappingURL=helpers.mjs.map
