"use strict";
const isSSR = Boolean(
  import.meta.env.SSR || import.meta.env.SSG || import.meta.env.VITE_SSR || import.meta.env.VITE_SSG
);
function kebabCase(key) {
  const result = key.replace(/([A-Z])/g, " $1").trim();
  return result.split(" ").join("-").toLowerCase();
}
function getSideEffects(dirName, options) {
  const { importStyle = true } = options;
  if (!importStyle || isSSR) {
    return;
  }
  const noStyleComps = ["on-click-outside"];
  if (noStyleComps.includes(dirName)) {
    return;
  }
  if (importStyle)
    return [
      "interface-ui/dist/styles/base.css",
      `interface-ui/dist/styles/${dirName}/src/index.css`
    ];
  return [`interface-ui/dist/lib/components/${dirName}/index.js`];
}
function PlayResolver(options = {}) {
  const { from = "interface-ui" } = options;
  return {
    type: "component",
    resolve: (name) => {
      if (name.startsWith("In")) {
        const partialName = name.slice(2);
        return {
          name,
          from,
          sideEffects: getSideEffects(kebabCase(partialName), options)
        };
      }
    }
  };
}

export { PlayResolver, isSSR, kebabCase };
//# sourceMappingURL=resolver.mjs.map
