'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../../../../utils/index.js');
require('../../../../theme/index.js');
var index = require('../../typography/index.js');
var badge = require('./badge.js');
var useNamespace = require('../../../../utils/src/dom/use-namespace.js');
var useColor = require('../../../../theme/src/hooks/use-color.js');
var emotionCss_esm = require('../../../../node_modules/.pnpm/@emotion_css@11.11.2/node_modules/@emotion/css/dist/emotion-css.esm.js');
var styled = require('../../../../theme/src/core/styled.js');
var error = require('../../../../utils/src/javascript/error.js');

"use strict";
var _sfc_main = /* @__PURE__ */ vue.defineComponent({
  __name: "index",
  props: badge.badgeProps,
  setup(__props) {
    const props = __props;
    const slots = vue.useSlots();
    const ns = useNamespace.useNamespace("badge");
    const [$color, $onColor] = useColor.useColor(props, "color");
    const translate = {
      top: "-50%",
      bottom: "50%",
      right: "50%",
      left: "-50%"
    };
    const positionCss = vue.computed(
      () => slots.default ? emotionCss_esm.css`
        ${props.xAlign}: 0;
        ${props.yAlign}: 0;
        position: absolute;
        transform: scale(1)
          translate(
            ${props.overlap ? "0%" : translate[props.xAlign]},
            ${props.overlap ? "0%" : translate[props.yAlign]}
          );
      ` : ""
    );
    const BadgeTypography = vue.computed(
      () => styled.styled(index.InTypography, { color: $onColor.value })`
    background-color: ${$color.value};
    height: ${props.variant === "dot" ? "8px" : "20px"};
    min-width: ${props.variant === "dot" ? "8px" : "20px"};
    border-radius: 10px;
    padding: ${props.variant === "dot" ? "0" : "6px"} !important;
  `
    );
    const showTypography = vue.computed(() => {
      const { content, variant } = props;
      return variant === "dot" || ["string", "number"].includes(typeof content);
    });
    const badgeContent = vue.computed(() => {
      const { content, max } = props;
      if (!showTypography.value) {
        return null;
      }
      if (content && max) {
        if (!["string", "number"].includes(typeof content)) {
          error.debugWarn(
            "[Interface UI]",
            'props.content can only be "string" or "number" when set props.max'
          );
          return null;
        }
        return max ? +max < +content ? `${max}+` : content : content;
      }
      return content;
    });
    return (_ctx, _cache) => {
      return vue.openBlock(), vue.createElementBlock(
        "span",
        {
          class: vue.normalizeClass(vue.unref(ns).b())
        },
        [
          vue.renderSlot(_ctx.$slots, "default"),
          showTypography.value ? (vue.openBlock(), vue.createBlock(vue.unref(BadgeTypography), {
            key: 0,
            class: vue.normalizeClass([vue.unref(ns).m("icon"), positionCss.value]),
            variant: "label.small"
          }, {
            default: vue.withCtx(() => [
              props.variant !== "dot" ? (vue.openBlock(), vue.createElementBlock(
                vue.Fragment,
                { key: 0 },
                [
                  vue.createTextVNode(
                    vue.toDisplayString(badgeContent.value),
                    1
                    /* TEXT */
                  )
                ],
                64
                /* STABLE_FRAGMENT */
              )) : vue.createCommentVNode("v-if", true)
            ]),
            _: 1
            /* STABLE */
          }, 8, ["class"])) : (vue.openBlock(), vue.createBlock(props.content, {
            key: 1,
            class: vue.normalizeClass([vue.unref(ns).m("icon"), positionCss.value])
          }, null, 8, ["class"]))
        ],
        2
        /* CLASS */
      );
    };
  }
});

exports.default = _sfc_main;
//# sourceMappingURL=index.vue2.js.map
