'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../../../../utils/index.js');
var index = require('../../alert/index.js');
var index$1 = require('../../typography/index.js');
var notistack = require('./notistack.vue.js');
var index_jss = require('./index.jss.js');
var id = require('../../../../utils/src/dom/id.js');
var check = require('../../../../utils/src/javascript/check.js');
var singleton = require('../../../../utils/src/javascript/singleton.js');

"use strict";
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !vue.isVNode(s);
}
class InMessageClass {
  constructor(props = {}) {
    this._rendered = false;
    this._body = document.body;
    this._notistack = vue.createVNode(notistack.default, null, null);
    this._defaultProps = {
      title: "",
      variant: "filled",
      severity: "info",
      icon: true,
      customIcon: void 0,
      action: void 0,
      actionEvent: (node) => {
        this._removeMessage(node.id);
      },
      content: "",
      duration: 2e3,
      transition: "all 0.5s ease",
      placement: {
        x: "right",
        y: "top"
      }
    };
    this._handleMouseenter = (timer) => {
      clearTimeout(timer);
      timer = null;
    };
    this._defaultProps = {
      ...this._defaultProps,
      ...props
    };
    const cssClass = index_jss.default(this._defaultProps);
    this._notistack = vue.createVNode(notistack.default, {
      "class": cssClass
    }, null);
    this._render();
  }
  _render() {
    if (!this._rendered) {
      vue.render(this._notistack, this._body);
      this._rendered = true;
    }
  }
  push(props = {}) {
    this._render();
    this._pushMessage(props);
  }
  _pushMessage(props = {}) {
    const {
      title,
      content,
      customIcon,
      action,
      actionEvent,
      duration,
      placement: _placement,
      transition: _transition,
      ...alertProps
    } = {
      ...this._defaultProps,
      ...props
    };
    let timer = null;
    const Alert = index.InAlert;
    const Icon = customIcon;
    const Action = action;
    const id$1 = id.generateId();
    const alertVNode = vue.createVNode(Alert, vue.mergeProps(alertProps, {
      "onMouseenter": () => this._handleMouseenter(timer),
      "onMouseleave": () => this._startTimer(alertVNode, duration)
    }), {
      icon: customIcon ? () => vue.createVNode(Icon, null, null) : void 0,
      default: () => vue.createVNode(vue.Fragment, null, [!check.isEmpty(title) && vue.createVNode(index$1.InTypography, {
        "variant": "title.medium",
        "component": "h1",
        "color": "inherit"
      }, _isSlot(title) ? title : {
        default: () => [title]
      }), content]),
      action: action ? (icon) => vue.createVNode(Action, vue.mergeProps(vue.mergeProps(icon, action.props), {
        "onClick": () => actionEvent(alertVNode, this._removeMessage.bind(this))
      }), null) : void 0
    });
    alertVNode.id = id$1;
    this._notistack.component?.exposed?.add(alertVNode);
    timer = this._startTimer(alertVNode, duration);
  }
  _removeMessage(condition) {
    this._notistack.component?.exposed?.remove(condition);
  }
  _startTimer(alertVNode, duration) {
    return setTimeout(() => {
      this._removeMessage(alertVNode.id);
    }, duration);
  }
  info(props = {}) {
    this.push({
      ...props,
      severity: "info"
    });
  }
  success(props = {}) {
    this.push({
      ...props,
      severity: "success"
    });
  }
  warning(props = {}) {
    this.push({
      ...props,
      severity: "warning"
    });
  }
  error(props = {}) {
    this.push({
      ...props,
      severity: "error"
    });
  }
  removeAll() {
    this._notistack.component?.exposed?.removeAll();
  }
  static install(app) {
    app.config.globalProperties.$message = singleton.singleton(InMessageClass);
  }
}
var InMessage = singleton.singleton(InMessageClass);

exports.InMessageClass = InMessageClass;
exports.default = InMessage;
//# sourceMappingURL=index.js.map
