'use strict';

var blend = require('./blend/blend.js');
var contrast = require('./contrast/contrast.js');
var dislike_analyzer = require('./dislike/dislike_analyzer.js');
var dynamic_color = require('./dynamiccolor/dynamic_color.js');
var material_dynamic_colors = require('./dynamiccolor/material_dynamic_colors.js');
var cam16 = require('./hct/cam16.js');
var hct = require('./hct/hct.js');
var viewing_conditions = require('./hct/viewing_conditions.js');
var core_palette = require('./palettes/core_palette.js');
var tonal_palette = require('./palettes/tonal_palette.js');
var quantizer_celebi = require('./quantize/quantizer_celebi.js');
var quantizer_map = require('./quantize/quantizer_map.js');
var quantizer_wsmeans = require('./quantize/quantizer_wsmeans.js');
var quantizer_wu = require('./quantize/quantizer_wu.js');
var dynamic_scheme = require('./scheme/dynamic_scheme.js');
var scheme = require('./scheme/scheme.js');
var scheme_android = require('./scheme/scheme_android.js');
var scheme_content = require('./scheme/scheme_content.js');
var scheme_expressive = require('./scheme/scheme_expressive.js');
var scheme_fidelity = require('./scheme/scheme_fidelity.js');
var scheme_monochrome = require('./scheme/scheme_monochrome.js');
var scheme_neutral = require('./scheme/scheme_neutral.js');
var scheme_tonal_spot = require('./scheme/scheme_tonal_spot.js');
var scheme_vibrant = require('./scheme/scheme_vibrant.js');
var score = require('./score/score.js');
var temperature_cache = require('./temperature/temperature_cache.js');
var color_utils = require('./utils/color_utils.js');
var math_utils = require('./utils/math_utils.js');
var string_utils = require('./utils/string_utils.js');
var image_utils = require('./utils/image_utils.js');
var theme_utils = require('./utils/theme_utils.js');

/**
 * @license
 * Copyright 2021 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

exports.Blend = blend.Blend;
exports.Contrast = contrast.Contrast;
exports.DislikeAnalyzer = dislike_analyzer.DislikeAnalyzer;
exports.DynamicColor = dynamic_color.DynamicColor;
exports.MaterialDynamicColors = material_dynamic_colors.MaterialDynamicColors;
exports.Cam16 = cam16.Cam16;
exports.Hct = hct.Hct;
exports.ViewingConditions = viewing_conditions.ViewingConditions;
exports.CorePalette = core_palette.CorePalette;
exports.TonalPalette = tonal_palette.TonalPalette;
exports.QuantizerCelebi = quantizer_celebi.QuantizerCelebi;
exports.QuantizerMap = quantizer_map.QuantizerMap;
exports.QuantizerWsmeans = quantizer_wsmeans.QuantizerWsmeans;
exports.QuantizerWu = quantizer_wu.QuantizerWu;
exports.DynamicScheme = dynamic_scheme.DynamicScheme;
exports.Scheme = scheme.Scheme;
exports.SchemeAndroid = scheme_android.SchemeAndroid;
exports.SchemeContent = scheme_content.SchemeContent;
exports.SchemeExpressive = scheme_expressive.SchemeExpressive;
exports.SchemeFidelity = scheme_fidelity.SchemeFidelity;
exports.SchemeMonochrome = scheme_monochrome.SchemeMonochrome;
exports.SchemeNeutral = scheme_neutral.SchemeNeutral;
exports.SchemeTonalSpot = scheme_tonal_spot.SchemeTonalSpot;
exports.SchemeVibrant = scheme_vibrant.SchemeVibrant;
exports.Score = score.Score;
exports.TemperatureCache = temperature_cache.TemperatureCache;
exports.alphaFromArgb = color_utils.alphaFromArgb;
exports.argbFromLab = color_utils.argbFromLab;
exports.argbFromLinrgb = color_utils.argbFromLinrgb;
exports.argbFromLstar = color_utils.argbFromLstar;
exports.argbFromRgb = color_utils.argbFromRgb;
exports.argbFromRgba = color_utils.argbFromRgba;
exports.argbFromXyz = color_utils.argbFromXyz;
exports.blueFromArgb = color_utils.blueFromArgb;
exports.delinearized = color_utils.delinearized;
exports.greenFromArgb = color_utils.greenFromArgb;
exports.isOpaque = color_utils.isOpaque;
exports.labFromArgb = color_utils.labFromArgb;
exports.linearized = color_utils.linearized;
exports.lstarFromArgb = color_utils.lstarFromArgb;
exports.lstarFromY = color_utils.lstarFromY;
exports.redFromArgb = color_utils.redFromArgb;
exports.rgbaFromArgb = color_utils.rgbaFromArgb;
exports.whitePointD65 = color_utils.whitePointD65;
exports.xyzFromArgb = color_utils.xyzFromArgb;
exports.yFromLstar = color_utils.yFromLstar;
exports.clampDouble = math_utils.clampDouble;
exports.clampInt = math_utils.clampInt;
exports.differenceDegrees = math_utils.differenceDegrees;
exports.lerp = math_utils.lerp;
exports.matrixMultiply = math_utils.matrixMultiply;
exports.rotationDirection = math_utils.rotationDirection;
exports.sanitizeDegreesDouble = math_utils.sanitizeDegreesDouble;
exports.sanitizeDegreesInt = math_utils.sanitizeDegreesInt;
exports.signum = math_utils.signum;
exports.argbFromHex = string_utils.argbFromHex;
exports.hexFromArgb = string_utils.hexFromArgb;
exports.sourceColorFromImage = image_utils.sourceColorFromImage;
exports.applyTheme = theme_utils.applyTheme;
exports.customColor = theme_utils.customColor;
exports.themeFromImage = theme_utils.themeFromImage;
exports.themeFromSourceColor = theme_utils.themeFromSourceColor;
//# sourceMappingURL=index.js.map
