'use strict';

var dislike_analyzer = require('../dislike/dislike_analyzer.js');
var tonal_palette = require('../palettes/tonal_palette.js');
var temperature_cache = require('../temperature/temperature_cache.js');
var dynamic_scheme = require('./dynamic_scheme.js');
var variant = require('./variant.js');

/**
 * @license
 * Copyright 2023 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * A scheme that places the source color in `Scheme.primaryContainer`.
 *
 * Primary Container is the source color, adjusted for color relativity.
 * It maintains constant appearance in light mode and dark mode.
 * This adds ~5 tone in light mode, and subtracts ~5 tone in dark mode.
 * Tertiary Container is the complement to the source color, using
 * `TemperatureCache`. It also maintains constant appearance.
 */
class SchemeFidelity extends dynamic_scheme.DynamicScheme {
    constructor(sourceColorHct, isDark, contrastLevel) {
        super({
            sourceColorArgb: sourceColorHct.toInt(),
            variant: variant.Variant.FIDELITY,
            contrastLevel,
            isDark,
            primaryPalette: tonal_palette.TonalPalette.fromHueAndChroma(sourceColorHct.hue, sourceColorHct.chroma),
            secondaryPalette: tonal_palette.TonalPalette.fromHueAndChroma(sourceColorHct.hue, Math.max(sourceColorHct.chroma - 32.0, sourceColorHct.chroma * 0.5)),
            tertiaryPalette: tonal_palette.TonalPalette.fromInt(dislike_analyzer.DislikeAnalyzer
                .fixIfDisliked(new temperature_cache.TemperatureCache(sourceColorHct).complement)
                .toInt()),
            neutralPalette: tonal_palette.TonalPalette.fromHueAndChroma(sourceColorHct.hue, sourceColorHct.chroma / 8.0),
            neutralVariantPalette: tonal_palette.TonalPalette.fromHueAndChroma(sourceColorHct.hue, sourceColorHct.chroma / 8.0 + 4.0),
        });
    }
}

exports.SchemeFidelity = SchemeFidelity;
//# sourceMappingURL=scheme_fidelity.js.map
