'use strict';

var tonal_palette = require('../palettes/tonal_palette.js');
var math_utils = require('../utils/math_utils.js');
var dynamic_scheme = require('./dynamic_scheme.js');
var variant = require('./variant.js');

/**
 * @license
 * Copyright 2022 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * A Dynamic Color theme with low to medium colorfulness and a Tertiary
 * TonalPalette with a hue related to the source color.
 *
 * The default Material You theme on Android 12 and 13.
 */
class SchemeTonalSpot extends dynamic_scheme.DynamicScheme {
    constructor(sourceColorHct, isDark, contrastLevel) {
        super({
            sourceColorArgb: sourceColorHct.toInt(),
            variant: variant.Variant.TONAL_SPOT,
            contrastLevel,
            isDark,
            primaryPalette: tonal_palette.TonalPalette.fromHueAndChroma(sourceColorHct.hue, 36.0),
            secondaryPalette: tonal_palette.TonalPalette.fromHueAndChroma(sourceColorHct.hue, 16.0),
            tertiaryPalette: tonal_palette.TonalPalette.fromHueAndChroma(math_utils.sanitizeDegreesDouble(sourceColorHct.hue + 60.0), 24.0),
            neutralPalette: tonal_palette.TonalPalette.fromHueAndChroma(sourceColorHct.hue, 6.0),
            neutralVariantPalette: tonal_palette.TonalPalette.fromHueAndChroma(sourceColorHct.hue, 8.0),
        });
    }
}

exports.SchemeTonalSpot = SchemeTonalSpot;
//# sourceMappingURL=scheme_tonal_spot.js.map
