'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _SetCache = require('./_SetCache.js');
var _arrayIncludes = require('./_arrayIncludes.js');
var _arrayIncludesWith = require('./_arrayIncludesWith.js');
var _arrayMap = require('./_arrayMap.js');
var _baseUnary = require('./_baseUnary.js');
var _cacheHas = require('./_cacheHas.js');

/** Used as the size to enable large array optimizations. */
var LARGE_ARRAY_SIZE = 200;

/**
 * The base implementation of methods like `_.difference` without support
 * for excluding multiple arrays or iteratee shorthands.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {Array} values The values to exclude.
 * @param {Function} [iteratee] The iteratee invoked per element.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new array of filtered values.
 */
function baseDifference(array, values, iteratee, comparator) {
  var index = -1,
      includes = _arrayIncludes.default,
      isCommon = true,
      length = array.length,
      result = [],
      valuesLength = values.length;

  if (!length) {
    return result;
  }
  if (iteratee) {
    values = _arrayMap.default(values, _baseUnary.default(iteratee));
  }
  if (comparator) {
    includes = _arrayIncludesWith.default;
    isCommon = false;
  }
  else if (values.length >= LARGE_ARRAY_SIZE) {
    includes = _cacheHas.default;
    isCommon = false;
    values = new _SetCache.default(values);
  }
  outer:
  while (++index < length) {
    var value = array[index],
        computed = iteratee == null ? value : iteratee(value);

    value = (comparator || value !== 0) ? value : 0;
    if (isCommon && computed === computed) {
      var valuesIndex = valuesLength;
      while (valuesIndex--) {
        if (values[valuesIndex] === computed) {
          continue outer;
        }
      }
      result.push(value);
    }
    else if (!includes(values, computed, comparator)) {
      result.push(value);
    }
  }
  return result;
}

exports.default = baseDifference;
//# sourceMappingURL=_baseDifference.js.map
