'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var toInteger = require('./toInteger.js');
var toLength = require('./toLength.js');

/**
 * The base implementation of `_.fill` without an iteratee call guard.
 *
 * @private
 * @param {Array} array The array to fill.
 * @param {*} value The value to fill `array` with.
 * @param {number} [start=0] The start position.
 * @param {number} [end=array.length] The end position.
 * @returns {Array} Returns `array`.
 */
function baseFill(array, value, start, end) {
  var length = array.length;

  start = toInteger.default(start);
  if (start < 0) {
    start = -start > length ? 0 : (length + start);
  }
  end = (end === undefined || end > length) ? length : toInteger.default(end);
  if (end < 0) {
    end += length;
  }
  end = start > end ? 0 : toLength.default(end);
  while (start < end) {
    array[start++] = value;
  }
  return array;
}

exports.default = baseFill;
//# sourceMappingURL=_baseFill.js.map
