'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseMatches = require('./_baseMatches.js');
var _baseMatchesProperty = require('./_baseMatchesProperty.js');
var identity = require('./identity.js');
var isArray = require('./isArray.js');
var property = require('./property.js');

/**
 * The base implementation of `_.iteratee`.
 *
 * @private
 * @param {*} [value=_.identity] The value to convert to an iteratee.
 * @returns {Function} Returns the iteratee.
 */
function baseIteratee(value) {
  // Don't store the `typeof` result in a variable to avoid a JIT bug in Safari 9.
  // See https://bugs.webkit.org/show_bug.cgi?id=156034 for more details.
  if (typeof value == 'function') {
    return value;
  }
  if (value == null) {
    return identity.default;
  }
  if (typeof value == 'object') {
    return isArray.default(value)
      ? _baseMatchesProperty.default(value[0], value[1])
      : _baseMatches.default(value);
  }
  return property.default(value);
}

exports.default = baseIteratee;
//# sourceMappingURL=_baseIteratee.js.map
