'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseEach = require('./_baseEach.js');
var isArrayLike = require('./isArrayLike.js');

/**
 * The base implementation of `_.map` without support for iteratee shorthands.
 *
 * @private
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Function} iteratee The function invoked per iteration.
 * @returns {Array} Returns the new mapped array.
 */
function baseMap(collection, iteratee) {
  var index = -1,
      result = isArrayLike.default(collection) ? Array(collection.length) : [];

  _baseEach.default(collection, function(value, key, collection) {
    result[++index] = iteratee(value, key, collection);
  });
  return result;
}

exports.default = baseMap;
//# sourceMappingURL=_baseMap.js.map
