'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _Stack = require('./_Stack.js');
var _assignMergeValue = require('./_assignMergeValue.js');
var _baseFor = require('./_baseFor.js');
var _baseMergeDeep = require('./_baseMergeDeep.js');
var isObject = require('./isObject.js');
var keysIn = require('./keysIn.js');
var _safeGet = require('./_safeGet.js');

/**
 * The base implementation of `_.merge` without support for multiple sources.
 *
 * @private
 * @param {Object} object The destination object.
 * @param {Object} source The source object.
 * @param {number} srcIndex The index of `source`.
 * @param {Function} [customizer] The function to customize merged values.
 * @param {Object} [stack] Tracks traversed source values and their merged
 *  counterparts.
 */
function baseMerge(object, source, srcIndex, customizer, stack) {
  if (object === source) {
    return;
  }
  _baseFor.default(source, function(srcValue, key) {
    stack || (stack = new _Stack.default);
    if (isObject.default(srcValue)) {
      _baseMergeDeep.default(object, source, key, srcIndex, baseMerge, customizer, stack);
    }
    else {
      var newValue = customizer
        ? customizer(_safeGet.default(object, key), srcValue, (key + ''), object, source, stack)
        : undefined;

      if (newValue === undefined) {
        newValue = srcValue;
      }
      _assignMergeValue.default(object, key, newValue);
    }
  }, keysIn.default);
}

exports.default = baseMerge;
//# sourceMappingURL=_baseMerge.js.map
