'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayMap = require('./_arrayMap.js');
var _baseGet = require('./_baseGet.js');
var _baseIteratee = require('./_baseIteratee.js');
var _baseMap = require('./_baseMap.js');
var _baseSortBy = require('./_baseSortBy.js');
var _baseUnary = require('./_baseUnary.js');
var _compareMultiple = require('./_compareMultiple.js');
var identity = require('./identity.js');
var isArray = require('./isArray.js');

/**
 * The base implementation of `_.orderBy` without param guards.
 *
 * @private
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Function[]|Object[]|string[]} iteratees The iteratees to sort by.
 * @param {string[]} orders The sort orders of `iteratees`.
 * @returns {Array} Returns the new sorted array.
 */
function baseOrderBy(collection, iteratees, orders) {
  if (iteratees.length) {
    iteratees = _arrayMap.default(iteratees, function(iteratee) {
      if (isArray.default(iteratee)) {
        return function(value) {
          return _baseGet.default(value, iteratee.length === 1 ? iteratee[0] : iteratee);
        }
      }
      return iteratee;
    });
  } else {
    iteratees = [identity.default];
  }

  var index = -1;
  iteratees = _arrayMap.default(iteratees, _baseUnary.default(_baseIteratee.default));

  var result = _baseMap.default(collection, function(value, key, collection) {
    var criteria = _arrayMap.default(iteratees, function(iteratee) {
      return iteratee(value);
    });
    return { 'criteria': criteria, 'index': ++index, 'value': value };
  });

  return _baseSortBy.default(result, function(object, other) {
    return _compareMultiple.default(object, other, orders);
  });
}

exports.default = baseOrderBy;
//# sourceMappingURL=_baseOrderBy.js.map
