'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _assignValue = require('./_assignValue.js');
var _castPath = require('./_castPath.js');
var _isIndex = require('./_isIndex.js');
var isObject = require('./isObject.js');
var _toKey = require('./_toKey.js');

/**
 * The base implementation of `_.set`.
 *
 * @private
 * @param {Object} object The object to modify.
 * @param {Array|string} path The path of the property to set.
 * @param {*} value The value to set.
 * @param {Function} [customizer] The function to customize path creation.
 * @returns {Object} Returns `object`.
 */
function baseSet(object, path, value, customizer) {
  if (!isObject.default(object)) {
    return object;
  }
  path = _castPath.default(path, object);

  var index = -1,
      length = path.length,
      lastIndex = length - 1,
      nested = object;

  while (nested != null && ++index < length) {
    var key = _toKey.default(path[index]),
        newValue = value;

    if (key === '__proto__' || key === 'constructor' || key === 'prototype') {
      return object;
    }

    if (index != lastIndex) {
      var objValue = nested[key];
      newValue = customizer ? customizer(objValue, key, nested) : undefined;
      if (newValue === undefined) {
        newValue = isObject.default(objValue)
          ? objValue
          : (_isIndex.default(path[index + 1]) ? [] : {});
      }
    }
    _assignValue.default(nested, key, newValue);
    nested = nested[key];
  }
  return object;
}

exports.default = baseSet;
//# sourceMappingURL=_baseSet.js.map
