'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _SetCache = require('./_SetCache.js');
var _arrayIncludes = require('./_arrayIncludes.js');
var _arrayIncludesWith = require('./_arrayIncludesWith.js');
var _cacheHas = require('./_cacheHas.js');
var _createSet = require('./_createSet.js');
var _setToArray = require('./_setToArray.js');

/** Used as the size to enable large array optimizations. */
var LARGE_ARRAY_SIZE = 200;

/**
 * The base implementation of `_.uniqBy` without support for iteratee shorthands.
 *
 * @private
 * @param {Array} array The array to inspect.
 * @param {Function} [iteratee] The iteratee invoked per element.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new duplicate free array.
 */
function baseUniq(array, iteratee, comparator) {
  var index = -1,
      includes = _arrayIncludes.default,
      length = array.length,
      isCommon = true,
      result = [],
      seen = result;

  if (comparator) {
    isCommon = false;
    includes = _arrayIncludesWith.default;
  }
  else if (length >= LARGE_ARRAY_SIZE) {
    var set = iteratee ? null : _createSet.default(array);
    if (set) {
      return _setToArray.default(set);
    }
    isCommon = false;
    includes = _cacheHas.default;
    seen = new _SetCache.default;
  }
  else {
    seen = iteratee ? [] : result;
  }
  outer:
  while (++index < length) {
    var value = array[index],
        computed = iteratee ? iteratee(value) : value;

    value = (comparator || value !== 0) ? value : 0;
    if (isCommon && computed === computed) {
      var seenIndex = seen.length;
      while (seenIndex--) {
        if (seen[seenIndex] === computed) {
          continue outer;
        }
      }
      if (iteratee) {
        seen.push(computed);
      }
      result.push(value);
    }
    else if (!includes(seen, computed, comparator)) {
      if (seen !== result) {
        seen.push(computed);
      }
      result.push(value);
    }
  }
  return result;
}

exports.default = baseUniq;
//# sourceMappingURL=_baseUniq.js.map
