'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseDifference = require('./_baseDifference.js');
var _baseFlatten = require('./_baseFlatten.js');
var _baseUniq = require('./_baseUniq.js');

/**
 * The base implementation of methods like `_.xor`, without support for
 * iteratee shorthands, that accepts an array of arrays to inspect.
 *
 * @private
 * @param {Array} arrays The arrays to inspect.
 * @param {Function} [iteratee] The iteratee invoked per element.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new array of values.
 */
function baseXor(arrays, iteratee, comparator) {
  var length = arrays.length;
  if (length < 2) {
    return length ? _baseUniq.default(arrays[0]) : [];
  }
  var index = -1,
      result = Array(length);

  while (++index < length) {
    var array = arrays[index],
        othIndex = -1;

    while (++othIndex < length) {
      if (othIndex != index) {
        result[index] = _baseDifference.default(result[index] || array, arrays[othIndex], iteratee, comparator);
      }
    }
  }
  return _baseUniq.default(_baseFlatten.default(result, 1), iteratee, comparator);
}

exports.default = baseXor;
//# sourceMappingURL=_baseXor.js.map
