'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayAggregator = require('./_arrayAggregator.js');
var _baseAggregator = require('./_baseAggregator.js');
var _baseIteratee = require('./_baseIteratee.js');
var isArray = require('./isArray.js');

/**
 * Creates a function like `_.groupBy`.
 *
 * @private
 * @param {Function} setter The function to set accumulator values.
 * @param {Function} [initializer] The accumulator object initializer.
 * @returns {Function} Returns the new aggregator function.
 */
function createAggregator(setter, initializer) {
  return function(collection, iteratee) {
    var func = isArray.default(collection) ? _arrayAggregator.default : _baseAggregator.default,
        accumulator = initializer ? initializer() : {};

    return func(collection, setter, _baseIteratee.default(iteratee, 2), accumulator);
  };
}

exports.default = createAggregator;
//# sourceMappingURL=_createAggregator.js.map
