'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _castSlice = require('./_castSlice.js');
var _hasUnicode = require('./_hasUnicode.js');
var _stringToArray = require('./_stringToArray.js');
var toString = require('./toString.js');

/**
 * Creates a function like `_.lowerFirst`.
 *
 * @private
 * @param {string} methodName The name of the `String` case method to use.
 * @returns {Function} Returns the new case function.
 */
function createCaseFirst(methodName) {
  return function(string) {
    string = toString.default(string);

    var strSymbols = _hasUnicode.default(string)
      ? _stringToArray.default(string)
      : undefined;

    var chr = strSymbols
      ? strSymbols[0]
      : string.charAt(0);

    var trailing = strSymbols
      ? _castSlice.default(strSymbols, 1).join('')
      : string.slice(1);

    return chr[methodName]() + trailing;
  };
}

exports.default = createCaseFirst;
//# sourceMappingURL=_createCaseFirst.js.map
