'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _apply = require('./_apply.js');
var _createCtor = require('./_createCtor.js');
var _createHybrid = require('./_createHybrid.js');
var _createRecurry = require('./_createRecurry.js');
var _getHolder = require('./_getHolder.js');
var _replaceHolders = require('./_replaceHolders.js');
var _root = require('./_root.js');

/**
 * Creates a function that wraps `func` to enable currying.
 *
 * @private
 * @param {Function} func The function to wrap.
 * @param {number} bitmask The bitmask flags. See `createWrap` for more details.
 * @param {number} arity The arity of `func`.
 * @returns {Function} Returns the new wrapped function.
 */
function createCurry(func, bitmask, arity) {
  var Ctor = _createCtor.default(func);

  function wrapper() {
    var length = arguments.length,
        args = Array(length),
        index = length,
        placeholder = _getHolder.default(wrapper);

    while (index--) {
      args[index] = arguments[index];
    }
    var holders = (length < 3 && args[0] !== placeholder && args[length - 1] !== placeholder)
      ? []
      : _replaceHolders.default(args, placeholder);

    length -= holders.length;
    if (length < arity) {
      return _createRecurry.default(
        func, bitmask, _createHybrid.default, wrapper.placeholder, undefined,
        args, holders, undefined, undefined, arity - length);
    }
    var fn = (this && this !== _root.default && this instanceof wrapper) ? Ctor : func;
    return _apply.default(fn, this, args);
  }
  return wrapper;
}

exports.default = createCurry;
//# sourceMappingURL=_createCurry.js.map
