'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _apply = require('./_apply.js');
var _arrayMap = require('./_arrayMap.js');
var _baseIteratee = require('./_baseIteratee.js');
var _baseRest = require('./_baseRest.js');
var _baseUnary = require('./_baseUnary.js');
var _flatRest = require('./_flatRest.js');

/**
 * Creates a function like `_.over`.
 *
 * @private
 * @param {Function} arrayFunc The function to iterate over iteratees.
 * @returns {Function} Returns the new over function.
 */
function createOver(arrayFunc) {
  return _flatRest.default(function(iteratees) {
    iteratees = _arrayMap.default(iteratees, _baseUnary.default(_baseIteratee.default));
    return _baseRest.default(function(args) {
      var thisArg = this;
      return arrayFunc(iteratees, function(iteratee) {
        return _apply.default(iteratee, thisArg, args);
      });
    });
  });
}

exports.default = createOver;
//# sourceMappingURL=_createOver.js.map
