'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseRepeat = require('./_baseRepeat.js');
var _baseToString = require('./_baseToString.js');
var _castSlice = require('./_castSlice.js');
var _hasUnicode = require('./_hasUnicode.js');
var _stringSize = require('./_stringSize.js');
var _stringToArray = require('./_stringToArray.js');

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeCeil = Math.ceil;

/**
 * Creates the padding for `string` based on `length`. The `chars` string
 * is truncated if the number of characters exceeds `length`.
 *
 * @private
 * @param {number} length The padding length.
 * @param {string} [chars=' '] The string used as padding.
 * @returns {string} Returns the padding for `string`.
 */
function createPadding(length, chars) {
  chars = chars === undefined ? ' ' : _baseToString.default(chars);

  var charsLength = chars.length;
  if (charsLength < 2) {
    return charsLength ? _baseRepeat.default(chars, length) : chars;
  }
  var result = _baseRepeat.default(chars, nativeCeil(length / _stringSize.default(chars)));
  return _hasUnicode.default(chars)
    ? _castSlice.default(_stringToArray.default(result), 0, length).join('')
    : result.slice(0, length);
}

exports.default = createPadding;
//# sourceMappingURL=_createPadding.js.map
