'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _root = require('./_root.js');
var toInteger = require('./toInteger.js');
var toNumber = require('./toNumber.js');
var toString = require('./toString.js');

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeIsFinite = _root.default.isFinite,
    nativeMin = Math.min;

/**
 * Creates a function like `_.round`.
 *
 * @private
 * @param {string} methodName The name of the `Math` method to use when rounding.
 * @returns {Function} Returns the new round function.
 */
function createRound(methodName) {
  var func = Math[methodName];
  return function(number, precision) {
    number = toNumber.default(number);
    precision = precision == null ? 0 : nativeMin(toInteger.default(precision), 292);
    if (precision && nativeIsFinite(number)) {
      // Shift with exponential notation to avoid floating-point issues.
      // See [MDN](https://mdn.io/round#Examples) for more details.
      var pair = (toString.default(number) + 'e').split('e'),
          value = func(pair[0] + 'e' + (+pair[1] + precision));

      pair = (toString.default(value) + 'e').split('e');
      return +(pair[0] + 'e' + (+pair[1] - precision));
    }
    return func(number);
  };
}

exports.default = createRound;
//# sourceMappingURL=_createRound.js.map
