'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseToPairs = require('./_baseToPairs.js');
var _getTag = require('./_getTag.js');
var _mapToArray = require('./_mapToArray.js');
var _setToPairs = require('./_setToPairs.js');

/** `Object#toString` result references. */
var mapTag = '[object Map]',
    setTag = '[object Set]';

/**
 * Creates a `_.toPairs` or `_.toPairsIn` function.
 *
 * @private
 * @param {Function} keysFunc The function to get the keys of a given object.
 * @returns {Function} Returns the new pairs function.
 */
function createToPairs(keysFunc) {
  return function(object) {
    var tag = _getTag.default(object);
    if (tag == mapTag) {
      return _mapToArray.default(object);
    }
    if (tag == setTag) {
      return _setToPairs.default(object);
    }
    return _baseToPairs.default(object, keysFunc(object));
  };
}

exports.default = createToPairs;
//# sourceMappingURL=_createToPairs.js.map
