'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var eq = require('./eq.js');
var isArrayLike = require('./isArrayLike.js');
var _isIndex = require('./_isIndex.js');
var isObject = require('./isObject.js');

/**
 * Checks if the given arguments are from an iteratee call.
 *
 * @private
 * @param {*} value The potential iteratee value argument.
 * @param {*} index The potential iteratee index or key argument.
 * @param {*} object The potential iteratee object argument.
 * @returns {boolean} Returns `true` if the arguments are from an iteratee call,
 *  else `false`.
 */
function isIterateeCall(value, index, object) {
  if (!isObject.default(object)) {
    return false;
  }
  var type = typeof index;
  if (type == 'number'
        ? (isArrayLike.default(object) && _isIndex.default(index, object.length))
        : (type == 'string' && index in object)
      ) {
    return eq.default(object[index], value);
  }
  return false;
}

exports.default = isIterateeCall;
//# sourceMappingURL=_isIterateeCall.js.map
