'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _LazyWrapper = require('./_LazyWrapper.js');
var _getData = require('./_getData.js');
var _getFuncName = require('./_getFuncName.js');
var wrapperLodash = require('./wrapperLodash.js');

/**
 * Checks if `func` has a lazy counterpart.
 *
 * @private
 * @param {Function} func The function to check.
 * @returns {boolean} Returns `true` if `func` has a lazy counterpart,
 *  else `false`.
 */
function isLaziable(func) {
  var funcName = _getFuncName.default(func),
      other = wrapperLodash.default[funcName];

  if (typeof other != 'function' || !(funcName in _LazyWrapper.default.prototype)) {
    return false;
  }
  if (func === other) {
    return true;
  }
  var data = _getData.default(other);
  return !!data && func === data[0];
}

exports.default = isLaziable;
//# sourceMappingURL=_isLaziable.js.map
