'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _apply = require('./_apply.js');
var _baseRest = require('./_baseRest.js');
var isError = require('./isError.js');

/**
 * Attempts to invoke `func`, returning either the result or the caught error
 * object. Any additional arguments are provided to `func` when it's invoked.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Util
 * @param {Function} func The function to attempt.
 * @param {...*} [args] The arguments to invoke `func` with.
 * @returns {*} Returns the `func` result or error object.
 * @example
 *
 * // Avoid throwing errors for invalid selectors.
 * var elements = _.attempt(function(selector) {
 *   return document.querySelectorAll(selector);
 * }, '>_>');
 *
 * if (_.isError(elements)) {
 *   elements = [];
 * }
 */
var attempt = _baseRest.default(function(func, args) {
  try {
    return _apply.default(func, undefined, args);
  } catch (e) {
    return isError.default(e) ? e : new Error(e);
  }
});

exports.default = attempt;
//# sourceMappingURL=attempt.js.map
