'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayEach = require('./_arrayEach.js');
var _baseAssignValue = require('./_baseAssignValue.js');
var bind = require('./bind.js');
var _flatRest = require('./_flatRest.js');
var _toKey = require('./_toKey.js');

/**
 * Binds methods of an object to the object itself, overwriting the existing
 * method.
 *
 * **Note:** This method doesn't set the "length" property of bound functions.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Util
 * @param {Object} object The object to bind and assign the bound methods to.
 * @param {...(string|string[])} methodNames The object method names to bind.
 * @returns {Object} Returns `object`.
 * @example
 *
 * var view = {
 *   'label': 'docs',
 *   'click': function() {
 *     console.log('clicked ' + this.label);
 *   }
 * };
 *
 * _.bindAll(view, ['click']);
 * jQuery(element).on('click', view.click);
 * // => Logs 'clicked docs' when clicked.
 */
var bindAll = _flatRest.default(function(object, methodNames) {
  _arrayEach.default(methodNames, function(key) {
    key = _toKey.default(key);
    _baseAssignValue.default(object, key, bind.default(object[key], object));
  });
  return object;
});

exports.default = bindAll;
//# sourceMappingURL=bindAll.js.map
