'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayPush = require('./_arrayPush.js');
var _baseFlatten = require('./_baseFlatten.js');
var _copyArray = require('./_copyArray.js');
var isArray = require('./isArray.js');

/**
 * Creates a new array concatenating `array` with any additional arrays
 * and/or values.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Array
 * @param {Array} array The array to concatenate.
 * @param {...*} [values] The values to concatenate.
 * @returns {Array} Returns the new concatenated array.
 * @example
 *
 * var array = [1];
 * var other = _.concat(array, 2, [3], [[4]]);
 *
 * console.log(other);
 * // => [1, 2, 3, [4]]
 *
 * console.log(array);
 * // => [1]
 */
function concat() {
  var length = arguments.length;
  if (!length) {
    return [];
  }
  var args = Array(length - 1),
      array = arguments[0],
      index = length;

  while (index--) {
    args[index - 1] = arguments[index];
  }
  return _arrayPush.default(isArray.default(array) ? _copyArray.default(array) : [array], _baseFlatten.default(args, 1));
}

exports.default = concat;
//# sourceMappingURL=concat.js.map
