'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseDelay = require('./_baseDelay.js');
var _baseRest = require('./_baseRest.js');
var toNumber = require('./toNumber.js');

/**
 * Invokes `func` after `wait` milliseconds. Any additional arguments are
 * provided to `func` when it's invoked.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Function
 * @param {Function} func The function to delay.
 * @param {number} wait The number of milliseconds to delay invocation.
 * @param {...*} [args] The arguments to invoke `func` with.
 * @returns {number} Returns the timer id.
 * @example
 *
 * _.delay(function(text) {
 *   console.log(text);
 * }, 1000, 'later');
 * // => Logs 'later' after one second.
 */
var delay = _baseRest.default(function(func, wait, args) {
  return _baseDelay.default(func, toNumber.default(wait) || 0, args);
});

exports.default = delay;
//# sourceMappingURL=delay.js.map
