'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseDifference = require('./_baseDifference.js');
var _baseFlatten = require('./_baseFlatten.js');
var _baseRest = require('./_baseRest.js');
var isArrayLikeObject = require('./isArrayLikeObject.js');

/**
 * Creates an array of `array` values not included in the other given arrays
 * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * for equality comparisons. The order and references of result values are
 * determined by the first array.
 *
 * **Note:** Unlike `_.pullAll`, this method returns a new array.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {Array} array The array to inspect.
 * @param {...Array} [values] The values to exclude.
 * @returns {Array} Returns the new array of filtered values.
 * @see _.without, _.xor
 * @example
 *
 * _.difference([2, 1], [2, 3]);
 * // => [1]
 */
var difference = _baseRest.default(function(array, values) {
  return isArrayLikeObject.default(array)
    ? _baseDifference.default(array, _baseFlatten.default(values, 1, isArrayLikeObject.default, true))
    : [];
});

exports.default = difference;
//# sourceMappingURL=difference.js.map
