'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseDifference = require('./_baseDifference.js');
var _baseFlatten = require('./_baseFlatten.js');
var _baseRest = require('./_baseRest.js');
var isArrayLikeObject = require('./isArrayLikeObject.js');
var last = require('./last.js');

/**
 * This method is like `_.difference` except that it accepts `comparator`
 * which is invoked to compare elements of `array` to `values`. The order and
 * references of result values are determined by the first array. The comparator
 * is invoked with two arguments: (arrVal, othVal).
 *
 * **Note:** Unlike `_.pullAllWith`, this method returns a new array.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Array
 * @param {Array} array The array to inspect.
 * @param {...Array} [values] The values to exclude.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new array of filtered values.
 * @example
 *
 * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
 *
 * _.differenceWith(objects, [{ 'x': 1, 'y': 2 }], _.isEqual);
 * // => [{ 'x': 2, 'y': 1 }]
 */
var differenceWith = _baseRest.default(function(array, values) {
  var comparator = last.default(values);
  if (isArrayLikeObject.default(comparator)) {
    comparator = undefined;
  }
  return isArrayLikeObject.default(array)
    ? _baseDifference.default(array, _baseFlatten.default(values, 1, isArrayLikeObject.default, true), undefined, comparator)
    : [];
});

exports.default = differenceWith;
//# sourceMappingURL=differenceWith.js.map
