'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _createFind = require('./_createFind.js');
var findLastIndex = require('./findLastIndex.js');

/**
 * This method is like `_.find` except that it iterates over elements of
 * `collection` from right to left.
 *
 * @static
 * @memberOf _
 * @since 2.0.0
 * @category Collection
 * @param {Array|Object} collection The collection to inspect.
 * @param {Function} [predicate=_.identity] The function invoked per iteration.
 * @param {number} [fromIndex=collection.length-1] The index to search from.
 * @returns {*} Returns the matched element, else `undefined`.
 * @example
 *
 * _.findLast([1, 2, 3, 4], function(n) {
 *   return n % 2 == 1;
 * });
 * // => 3
 */
var findLast = _createFind.default(findLastIndex.default);

exports.default = findLast;
//# sourceMappingURL=findLast.js.map
