'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayEachRight = require('./_arrayEachRight.js');
var _baseEachRight = require('./_baseEachRight.js');
var _castFunction = require('./_castFunction.js');
var isArray = require('./isArray.js');

/**
 * This method is like `_.forEach` except that it iterates over elements of
 * `collection` from right to left.
 *
 * @static
 * @memberOf _
 * @since 2.0.0
 * @alias eachRight
 * @category Collection
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Function} [iteratee=_.identity] The function invoked per iteration.
 * @returns {Array|Object} Returns `collection`.
 * @see _.forEach
 * @example
 *
 * _.forEachRight([1, 2], function(value) {
 *   console.log(value);
 * });
 * // => Logs `2` then `1`.
 */
function forEachRight(collection, iteratee) {
  var func = isArray.default(collection) ? _arrayEachRight.default : _baseEachRight.default;
  return func(collection, _castFunction.default(iteratee));
}

exports.default = forEachRight;
//# sourceMappingURL=forEachRight.js.map
