'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayMap = require('./_arrayMap.js');
var _baseIntersection = require('./_baseIntersection.js');
var _baseRest = require('./_baseRest.js');
var _castArrayLikeObject = require('./_castArrayLikeObject.js');

/**
 * Creates an array of unique values that are included in all given arrays
 * using [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * for equality comparisons. The order and references of result values are
 * determined by the first array.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {...Array} [arrays] The arrays to inspect.
 * @returns {Array} Returns the new array of intersecting values.
 * @example
 *
 * _.intersection([2, 1], [2, 3]);
 * // => [2]
 */
var intersection = _baseRest.default(function(arrays) {
  var mapped = _arrayMap.default(arrays, _castArrayLikeObject.default);
  return (mapped.length && mapped[0] === arrays[0])
    ? _baseIntersection.default(mapped)
    : [];
});

exports.default = intersection;
//# sourceMappingURL=intersection.js.map
