'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var isArrayLike = require('./isArrayLike.js');
var isObjectLike = require('./isObjectLike.js');

/**
 * This method is like `_.isArrayLike` except that it also checks if `value`
 * is an object.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an array-like object,
 *  else `false`.
 * @example
 *
 * _.isArrayLikeObject([1, 2, 3]);
 * // => true
 *
 * _.isArrayLikeObject(document.body.children);
 * // => true
 *
 * _.isArrayLikeObject('abc');
 * // => false
 *
 * _.isArrayLikeObject(_.noop);
 * // => false
 */
function isArrayLikeObject(value) {
  return isObjectLike.default(value) && isArrayLike.default(value);
}

exports.default = isArrayLikeObject;
//# sourceMappingURL=isArrayLikeObject.js.map
