'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseGetTag = require('./_baseGetTag.js');
var isObjectLike = require('./isObjectLike.js');

/** `Object#toString` result references. */
var boolTag = '[object Boolean]';

/**
 * Checks if `value` is classified as a boolean primitive or object.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a boolean, else `false`.
 * @example
 *
 * _.isBoolean(false);
 * // => true
 *
 * _.isBoolean(null);
 * // => false
 */
function isBoolean(value) {
  return value === true || value === false ||
    (isObjectLike.default(value) && _baseGetTag.default(value) == boolTag);
}

exports.default = isBoolean;
//# sourceMappingURL=isBoolean.js.map
