'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseGetTag = require('./_baseGetTag.js');
var isObjectLike = require('./isObjectLike.js');
var isPlainObject = require('./isPlainObject.js');

/** `Object#toString` result references. */
var domExcTag = '[object DOMException]',
    errorTag = '[object Error]';

/**
 * Checks if `value` is an `Error`, `EvalError`, `RangeError`, `ReferenceError`,
 * `SyntaxError`, `TypeError`, or `URIError` object.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an error object, else `false`.
 * @example
 *
 * _.isError(new Error);
 * // => true
 *
 * _.isError(Error);
 * // => false
 */
function isError(value) {
  if (!isObjectLike.default(value)) {
    return false;
  }
  var tag = _baseGetTag.default(value);
  return tag == errorTag || tag == domExcTag ||
    (typeof value.message == 'string' && typeof value.name == 'string' && !isPlainObject.default(value));
}

exports.default = isError;
//# sourceMappingURL=isError.js.map
