'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseGetTag = require('./_baseGetTag.js');
var isArray = require('./isArray.js');
var isObjectLike = require('./isObjectLike.js');

/** `Object#toString` result references. */
var stringTag = '[object String]';

/**
 * Checks if `value` is classified as a `String` primitive or object.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a string, else `false`.
 * @example
 *
 * _.isString('abc');
 * // => true
 *
 * _.isString(1);
 * // => false
 */
function isString(value) {
  return typeof value == 'string' ||
    (!isArray.default(value) && isObjectLike.default(value) && _baseGetTag.default(value) == stringTag);
}

exports.default = isString;
//# sourceMappingURL=isString.js.map
