'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _getTag = require('./_getTag.js');
var isObjectLike = require('./isObjectLike.js');

/** `Object#toString` result references. */
var weakMapTag = '[object WeakMap]';

/**
 * Checks if `value` is classified as a `WeakMap` object.
 *
 * @static
 * @memberOf _
 * @since 4.3.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a weak map, else `false`.
 * @example
 *
 * _.isWeakMap(new WeakMap);
 * // => true
 *
 * _.isWeakMap(new Map);
 * // => false
 */
function isWeakMap(value) {
  return isObjectLike.default(value) && _getTag.default(value) == weakMapTag;
}

exports.default = isWeakMap;
//# sourceMappingURL=isWeakMap.js.map
