'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseGetTag = require('./_baseGetTag.js');
var isObjectLike = require('./isObjectLike.js');

/** `Object#toString` result references. */
var weakSetTag = '[object WeakSet]';

/**
 * Checks if `value` is classified as a `WeakSet` object.
 *
 * @static
 * @memberOf _
 * @since 4.3.0
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a weak set, else `false`.
 * @example
 *
 * _.isWeakSet(new WeakSet);
 * // => true
 *
 * _.isWeakSet(new Set);
 * // => false
 */
function isWeakSet(value) {
  return isObjectLike.default(value) && _baseGetTag.default(value) == weakSetTag;
}

exports.default = isWeakSet;
//# sourceMappingURL=isWeakSet.js.map
