'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayLikeKeys = require('./_arrayLikeKeys.js');
var _baseKeysIn = require('./_baseKeysIn.js');
var isArrayLike = require('./isArrayLike.js');

/**
 * Creates an array of the own and inherited enumerable property names of `object`.
 *
 * **Note:** Non-object values are coerced to objects.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Object
 * @param {Object} object The object to query.
 * @returns {Array} Returns the array of property names.
 * @example
 *
 * function Foo() {
 *   this.a = 1;
 *   this.b = 2;
 * }
 *
 * Foo.prototype.c = 3;
 *
 * _.keysIn(new Foo);
 * // => ['a', 'b', 'c'] (iteration order is not guaranteed)
 */
function keysIn(object) {
  return isArrayLike.default(object) ? _arrayLikeKeys.default(object, true) : _baseKeysIn.default(object);
}

exports.default = keysIn;
//# sourceMappingURL=keysIn.js.map
