'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseNth = require('./_baseNth.js');
var _baseRest = require('./_baseRest.js');
var toInteger = require('./toInteger.js');

/**
 * Creates a function that gets the argument at index `n`. If `n` is negative,
 * the nth argument from the end is returned.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Util
 * @param {number} [n=0] The index of the argument to return.
 * @returns {Function} Returns the new pass-thru function.
 * @example
 *
 * var func = _.nthArg(1);
 * func('a', 'b', 'c', 'd');
 * // => 'b'
 *
 * var func = _.nthArg(-2);
 * func('a', 'b', 'c', 'd');
 * // => 'c'
 */
function nthArg(n) {
  n = toInteger.default(n);
  return _baseRest.default(function(args) {
    return _baseNth.default(args, n);
  });
}

exports.default = nthArg;
//# sourceMappingURL=nthArg.js.map
