'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayMap = require('./_arrayMap.js');
var _baseIteratee = require('./_baseIteratee.js');
var _basePickBy = require('./_basePickBy.js');
var _getAllKeysIn = require('./_getAllKeysIn.js');

/**
 * Creates an object composed of the `object` properties `predicate` returns
 * truthy for. The predicate is invoked with two arguments: (value, key).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Object
 * @param {Object} object The source object.
 * @param {Function} [predicate=_.identity] The function invoked per property.
 * @returns {Object} Returns the new object.
 * @example
 *
 * var object = { 'a': 1, 'b': '2', 'c': 3 };
 *
 * _.pickBy(object, _.isNumber);
 * // => { 'a': 1, 'c': 3 }
 */
function pickBy(object, predicate) {
  if (object == null) {
    return {};
  }
  var props = _arrayMap.default(_getAllKeysIn.default(object), function(prop) {
    return [prop];
  });
  predicate = _baseIteratee.default(predicate);
  return _basePickBy.default(object, props, function(value, path) {
    return predicate(value, path[0]);
  });
}

exports.default = pickBy;
//# sourceMappingURL=pickBy.js.map
