'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseProperty = require('./_baseProperty.js');
var _basePropertyDeep = require('./_basePropertyDeep.js');
var _isKey = require('./_isKey.js');
var _toKey = require('./_toKey.js');

/**
 * Creates a function that returns the value at `path` of a given object.
 *
 * @static
 * @memberOf _
 * @since 2.4.0
 * @category Util
 * @param {Array|string} path The path of the property to get.
 * @returns {Function} Returns the new accessor function.
 * @example
 *
 * var objects = [
 *   { 'a': { 'b': 2 } },
 *   { 'a': { 'b': 1 } }
 * ];
 *
 * _.map(objects, _.property('a.b'));
 * // => [2, 1]
 *
 * _.map(_.sortBy(objects, _.property(['a', 'b'])), 'a.b');
 * // => [1, 2]
 */
function property(path) {
  return _isKey.default(path) ? _baseProperty.default(_toKey.default(path)) : _basePropertyDeep.default(path);
}

exports.default = property;
//# sourceMappingURL=property.js.map
