'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayMap = require('./_arrayMap.js');
var _baseAt = require('./_baseAt.js');
var _basePullAt = require('./_basePullAt.js');
var _compareAscending = require('./_compareAscending.js');
var _flatRest = require('./_flatRest.js');
var _isIndex = require('./_isIndex.js');

/**
 * Removes elements from `array` corresponding to `indexes` and returns an
 * array of removed elements.
 *
 * **Note:** Unlike `_.at`, this method mutates `array`.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category Array
 * @param {Array} array The array to modify.
 * @param {...(number|number[])} [indexes] The indexes of elements to remove.
 * @returns {Array} Returns the new array of removed elements.
 * @example
 *
 * var array = ['a', 'b', 'c', 'd'];
 * var pulled = _.pullAt(array, [1, 3]);
 *
 * console.log(array);
 * // => ['a', 'c']
 *
 * console.log(pulled);
 * // => ['b', 'd']
 */
var pullAt = _flatRest.default(function(array, indexes) {
  var length = array == null ? 0 : array.length,
      result = _baseAt.default(array, indexes);

  _basePullAt.default(array, _arrayMap.default(indexes, function(index) {
    return _isIndex.default(index, length) ? +index : index;
  }).sort(_compareAscending.default));

  return result;
});

exports.default = pullAt;
//# sourceMappingURL=pullAt.js.map
