'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayReduceRight = require('./_arrayReduceRight.js');
var _baseEachRight = require('./_baseEachRight.js');
var _baseIteratee = require('./_baseIteratee.js');
var _baseReduce = require('./_baseReduce.js');
var isArray = require('./isArray.js');

/**
 * This method is like `_.reduce` except that it iterates over elements of
 * `collection` from right to left.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Collection
 * @param {Array|Object} collection The collection to iterate over.
 * @param {Function} [iteratee=_.identity] The function invoked per iteration.
 * @param {*} [accumulator] The initial value.
 * @returns {*} Returns the accumulated value.
 * @see _.reduce
 * @example
 *
 * var array = [[0, 1], [2, 3], [4, 5]];
 *
 * _.reduceRight(array, function(flattened, other) {
 *   return flattened.concat(other);
 * }, []);
 * // => [4, 5, 2, 3, 0, 1]
 */
function reduceRight(collection, iteratee, accumulator) {
  var func = isArray.default(collection) ? _arrayReduceRight.default : _baseReduce.default,
      initAccum = arguments.length < 3;

  return func(collection, _baseIteratee.default(iteratee, 4), accumulator, initAccum, _baseEachRight.default);
}

exports.default = reduceRight;
//# sourceMappingURL=reduceRight.js.map
