'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseRepeat = require('./_baseRepeat.js');
var _isIterateeCall = require('./_isIterateeCall.js');
var toInteger = require('./toInteger.js');
var toString = require('./toString.js');

/**
 * Repeats the given string `n` times.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category String
 * @param {string} [string=''] The string to repeat.
 * @param {number} [n=1] The number of times to repeat the string.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
 * @returns {string} Returns the repeated string.
 * @example
 *
 * _.repeat('*', 3);
 * // => '***'
 *
 * _.repeat('abc', 2);
 * // => 'abcabc'
 *
 * _.repeat('abc', 0);
 * // => ''
 */
function repeat(string, n, guard) {
  if ((guard ? _isIterateeCall.default(string, n, guard) : n === undefined)) {
    n = 1;
  } else {
    n = toInteger.default(n);
  }
  return _baseRepeat.default(toString.default(string), n);
}

exports.default = repeat;
//# sourceMappingURL=repeat.js.map
