'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arraySampleSize = require('./_arraySampleSize.js');
var _baseSampleSize = require('./_baseSampleSize.js');
var isArray = require('./isArray.js');
var _isIterateeCall = require('./_isIterateeCall.js');
var toInteger = require('./toInteger.js');

/**
 * Gets `n` random elements at unique keys from `collection` up to the
 * size of `collection`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Collection
 * @param {Array|Object} collection The collection to sample.
 * @param {number} [n=1] The number of elements to sample.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
 * @returns {Array} Returns the random elements.
 * @example
 *
 * _.sampleSize([1, 2, 3], 2);
 * // => [3, 1]
 *
 * _.sampleSize([1, 2, 3], 4);
 * // => [2, 3, 1]
 */
function sampleSize(collection, n, guard) {
  if ((guard ? _isIterateeCall.default(collection, n, guard) : n === undefined)) {
    n = 1;
  } else {
    n = toInteger.default(n);
  }
  var func = isArray.default(collection) ? _arraySampleSize.default : _baseSampleSize.default;
  return func(collection, n);
}

exports.default = sampleSize;
//# sourceMappingURL=sampleSize.js.map
