'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseKeys = require('./_baseKeys.js');
var _getTag = require('./_getTag.js');
var isArrayLike = require('./isArrayLike.js');
var isString = require('./isString.js');
var _stringSize = require('./_stringSize.js');

/** `Object#toString` result references. */
var mapTag = '[object Map]',
    setTag = '[object Set]';

/**
 * Gets the size of `collection` by returning its length for array-like
 * values or the number of own enumerable string keyed properties for objects.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Collection
 * @param {Array|Object|string} collection The collection to inspect.
 * @returns {number} Returns the collection size.
 * @example
 *
 * _.size([1, 2, 3]);
 * // => 3
 *
 * _.size({ 'a': 1, 'b': 2 });
 * // => 2
 *
 * _.size('pebbles');
 * // => 7
 */
function size(collection) {
  if (collection == null) {
    return 0;
  }
  if (isArrayLike.default(collection)) {
    return isString.default(collection) ? _stringSize.default(collection) : collection.length;
  }
  var tag = _getTag.default(collection);
  if (tag == mapTag || tag == setTag) {
    return collection.size;
  }
  return _baseKeys.default(collection).length;
}

exports.default = size;
//# sourceMappingURL=size.js.map
