'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseIteratee = require('./_baseIteratee.js');
var _baseSortedUniq = require('./_baseSortedUniq.js');

/**
 * This method is like `_.uniqBy` except that it's designed and optimized
 * for sorted arrays.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Array
 * @param {Array} array The array to inspect.
 * @param {Function} [iteratee] The iteratee invoked per element.
 * @returns {Array} Returns the new duplicate free array.
 * @example
 *
 * _.sortedUniqBy([1.1, 1.2, 2.3, 2.4], Math.floor);
 * // => [1.1, 2.3]
 */
function sortedUniqBy(array, iteratee) {
  return (array && array.length)
    ? _baseSortedUniq.default(array, _baseIteratee.default(iteratee, 2))
    : [];
}

exports.default = sortedUniqBy;
//# sourceMappingURL=sortedUniqBy.js.map
