'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseToString = require('./_baseToString.js');
var _castSlice = require('./_castSlice.js');
var _hasUnicode = require('./_hasUnicode.js');
var _isIterateeCall = require('./_isIterateeCall.js');
var isRegExp = require('./isRegExp.js');
var _stringToArray = require('./_stringToArray.js');
var toString = require('./toString.js');

/** Used as references for the maximum length and index of an array. */
var MAX_ARRAY_LENGTH = 4294967295;

/**
 * Splits `string` by `separator`.
 *
 * **Note:** This method is based on
 * [`String#split`](https://mdn.io/String/split).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category String
 * @param {string} [string=''] The string to split.
 * @param {RegExp|string} separator The separator pattern to split by.
 * @param {number} [limit] The length to truncate results to.
 * @returns {Array} Returns the string segments.
 * @example
 *
 * _.split('a-b-c', '-', 2);
 * // => ['a', 'b']
 */
function split(string, separator, limit) {
  if (limit && typeof limit != 'number' && _isIterateeCall.default(string, separator, limit)) {
    separator = limit = undefined;
  }
  limit = limit === undefined ? MAX_ARRAY_LENGTH : limit >>> 0;
  if (!limit) {
    return [];
  }
  string = toString.default(string);
  if (string && (
        typeof separator == 'string' ||
        (separator != null && !isRegExp.default(separator))
      )) {
    separator = _baseToString.default(separator);
    if (!separator && _hasUnicode.default(string)) {
      return _castSlice.default(_stringToArray.default(string), 0, limit);
    }
  }
  return string.split(separator, limit);
}

exports.default = split;
//# sourceMappingURL=split.js.map
