'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _createCompounder = require('./_createCompounder.js');
var upperFirst = require('./upperFirst.js');

/**
 * Converts `string` to
 * [start case](https://en.wikipedia.org/wiki/Letter_case#Stylistic_or_specialised_usage).
 *
 * @static
 * @memberOf _
 * @since 3.1.0
 * @category String
 * @param {string} [string=''] The string to convert.
 * @returns {string} Returns the start cased string.
 * @example
 *
 * _.startCase('--foo-bar--');
 * // => 'Foo Bar'
 *
 * _.startCase('fooBar');
 * // => 'Foo Bar'
 *
 * _.startCase('__FOO_BAR__');
 * // => 'FOO BAR'
 */
var startCase = _createCompounder.default(function(result, word, index) {
  return result + (index ? ' ' : '') + upperFirst.default(word);
});

exports.default = startCase;
//# sourceMappingURL=startCase.js.map
