'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseClamp = require('./_baseClamp.js');
var _baseToString = require('./_baseToString.js');
var toInteger = require('./toInteger.js');
var toString = require('./toString.js');

/**
 * Checks if `string` starts with the given target string.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category String
 * @param {string} [string=''] The string to inspect.
 * @param {string} [target] The string to search for.
 * @param {number} [position=0] The position to search from.
 * @returns {boolean} Returns `true` if `string` starts with `target`,
 *  else `false`.
 * @example
 *
 * _.startsWith('abc', 'a');
 * // => true
 *
 * _.startsWith('abc', 'b');
 * // => false
 *
 * _.startsWith('abc', 'b', 1);
 * // => true
 */
function startsWith(string, target, position) {
  string = toString.default(string);
  position = position == null
    ? 0
    : _baseClamp.default(toInteger.default(position), 0, string.length);

  target = _baseToString.default(target);
  return string.slice(position, position + target.length) == target;
}

exports.default = startsWith;
//# sourceMappingURL=startsWith.js.map
