'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayMap = require('./_arrayMap.js');
var _copyArray = require('./_copyArray.js');
var isArray = require('./isArray.js');
var isSymbol = require('./isSymbol.js');
var _stringToPath = require('./_stringToPath.js');
var _toKey = require('./_toKey.js');
var toString = require('./toString.js');

/**
 * Converts `value` to a property path array.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Util
 * @param {*} value The value to convert.
 * @returns {Array} Returns the new property path array.
 * @example
 *
 * _.toPath('a.b.c');
 * // => ['a', 'b', 'c']
 *
 * _.toPath('a[0].b.c');
 * // => ['a', '0', 'b', 'c']
 */
function toPath(value) {
  if (isArray.default(value)) {
    return _arrayMap.default(value, _toKey.default);
  }
  return isSymbol.default(value) ? [value] : _copyArray.default(_stringToPath.default(toString.default(value)));
}

exports.default = toPath;
//# sourceMappingURL=toPath.js.map
