'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseToString = require('./_baseToString.js');
var _baseTrim = require('./_baseTrim.js');
var _castSlice = require('./_castSlice.js');
var _charsEndIndex = require('./_charsEndIndex.js');
var _charsStartIndex = require('./_charsStartIndex.js');
var _stringToArray = require('./_stringToArray.js');
var toString = require('./toString.js');

/**
 * Removes leading and trailing whitespace or specified characters from `string`.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category String
 * @param {string} [string=''] The string to trim.
 * @param {string} [chars=whitespace] The characters to trim.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
 * @returns {string} Returns the trimmed string.
 * @example
 *
 * _.trim('  abc  ');
 * // => 'abc'
 *
 * _.trim('-_-abc-_-', '_-');
 * // => 'abc'
 *
 * _.map(['  foo  ', '  bar  '], _.trim);
 * // => ['foo', 'bar']
 */
function trim(string, chars, guard) {
  string = toString.default(string);
  if (string && (guard || chars === undefined)) {
    return _baseTrim.default(string);
  }
  if (!string || !(chars = _baseToString.default(chars))) {
    return string;
  }
  var strSymbols = _stringToArray.default(string),
      chrSymbols = _stringToArray.default(chars),
      start = _charsStartIndex.default(strSymbols, chrSymbols),
      end = _charsEndIndex.default(strSymbols, chrSymbols) + 1;

  return _castSlice.default(strSymbols, start, end).join('');
}

exports.default = trim;
//# sourceMappingURL=trim.js.map
