'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseToString = require('./_baseToString.js');
var _castSlice = require('./_castSlice.js');
var _charsStartIndex = require('./_charsStartIndex.js');
var _stringToArray = require('./_stringToArray.js');
var toString = require('./toString.js');

/** Used to match leading whitespace. */
var reTrimStart = /^\s+/;

/**
 * Removes leading whitespace or specified characters from `string`.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category String
 * @param {string} [string=''] The string to trim.
 * @param {string} [chars=whitespace] The characters to trim.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
 * @returns {string} Returns the trimmed string.
 * @example
 *
 * _.trimStart('  abc  ');
 * // => 'abc  '
 *
 * _.trimStart('-_-abc-_-', '_-');
 * // => 'abc-_-'
 */
function trimStart(string, chars, guard) {
  string = toString.default(string);
  if (string && (guard || chars === undefined)) {
    return string.replace(reTrimStart, '');
  }
  if (!string || !(chars = _baseToString.default(chars))) {
    return string;
  }
  var strSymbols = _stringToArray.default(string),
      start = _charsStartIndex.default(strSymbols, _stringToArray.default(chars));

  return _castSlice.default(strSymbols, start).join('');
}

exports.default = trimStart;
//# sourceMappingURL=trimStart.js.map
