'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseFlatten = require('./_baseFlatten.js');
var _baseRest = require('./_baseRest.js');
var _baseUniq = require('./_baseUniq.js');
var isArrayLikeObject = require('./isArrayLikeObject.js');

/**
 * Creates an array of unique values, in order, from all given arrays using
 * [`SameValueZero`](http://ecma-international.org/ecma-262/7.0/#sec-samevaluezero)
 * for equality comparisons.
 *
 * @static
 * @memberOf _
 * @since 0.1.0
 * @category Array
 * @param {...Array} [arrays] The arrays to inspect.
 * @returns {Array} Returns the new array of combined values.
 * @example
 *
 * _.union([2], [1, 2]);
 * // => [2, 1]
 */
var union = _baseRest.default(function(arrays) {
  return _baseUniq.default(_baseFlatten.default(arrays, 1, isArrayLikeObject.default, true));
});

exports.default = union;
//# sourceMappingURL=union.js.map
