'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseFlatten = require('./_baseFlatten.js');
var _baseIteratee = require('./_baseIteratee.js');
var _baseRest = require('./_baseRest.js');
var _baseUniq = require('./_baseUniq.js');
var isArrayLikeObject = require('./isArrayLikeObject.js');
var last = require('./last.js');

/**
 * This method is like `_.union` except that it accepts `iteratee` which is
 * invoked for each element of each `arrays` to generate the criterion by
 * which uniqueness is computed. Result values are chosen from the first
 * array in which the value occurs. The iteratee is invoked with one argument:
 * (value).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Array
 * @param {...Array} [arrays] The arrays to inspect.
 * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
 * @returns {Array} Returns the new array of combined values.
 * @example
 *
 * _.unionBy([2.1], [1.2, 2.3], Math.floor);
 * // => [2.1, 1.2]
 *
 * // The `_.property` iteratee shorthand.
 * _.unionBy([{ 'x': 1 }], [{ 'x': 2 }, { 'x': 1 }], 'x');
 * // => [{ 'x': 1 }, { 'x': 2 }]
 */
var unionBy = _baseRest.default(function(arrays) {
  var iteratee = last.default(arrays);
  if (isArrayLikeObject.default(iteratee)) {
    iteratee = undefined;
  }
  return _baseUniq.default(_baseFlatten.default(arrays, 1, isArrayLikeObject.default, true), _baseIteratee.default(iteratee, 2));
});

exports.default = unionBy;
//# sourceMappingURL=unionBy.js.map
