'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _baseFlatten = require('./_baseFlatten.js');
var _baseRest = require('./_baseRest.js');
var _baseUniq = require('./_baseUniq.js');
var isArrayLikeObject = require('./isArrayLikeObject.js');
var last = require('./last.js');

/**
 * This method is like `_.union` except that it accepts `comparator` which
 * is invoked to compare elements of `arrays`. Result values are chosen from
 * the first array in which the value occurs. The comparator is invoked
 * with two arguments: (arrVal, othVal).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Array
 * @param {...Array} [arrays] The arrays to inspect.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new array of combined values.
 * @example
 *
 * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
 * var others = [{ 'x': 1, 'y': 1 }, { 'x': 1, 'y': 2 }];
 *
 * _.unionWith(objects, others, _.isEqual);
 * // => [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }, { 'x': 1, 'y': 1 }]
 */
var unionWith = _baseRest.default(function(arrays) {
  var comparator = last.default(arrays);
  comparator = typeof comparator == 'function' ? comparator : undefined;
  return _baseUniq.default(_baseFlatten.default(arrays, 1, isArrayLikeObject.default, true), undefined, comparator);
});

exports.default = unionWith;
//# sourceMappingURL=unionWith.js.map
