'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayFilter = require('./_arrayFilter.js');
var _arrayMap = require('./_arrayMap.js');
var _baseProperty = require('./_baseProperty.js');
var _baseTimes = require('./_baseTimes.js');
var isArrayLikeObject = require('./isArrayLikeObject.js');

/* Built-in method references for those with the same name as other `lodash` methods. */
var nativeMax = Math.max;

/**
 * This method is like `_.zip` except that it accepts an array of grouped
 * elements and creates an array regrouping the elements to their pre-zip
 * configuration.
 *
 * @static
 * @memberOf _
 * @since 1.2.0
 * @category Array
 * @param {Array} array The array of grouped elements to process.
 * @returns {Array} Returns the new array of regrouped elements.
 * @example
 *
 * var zipped = _.zip(['a', 'b'], [1, 2], [true, false]);
 * // => [['a', 1, true], ['b', 2, false]]
 *
 * _.unzip(zipped);
 * // => [['a', 'b'], [1, 2], [true, false]]
 */
function unzip(array) {
  if (!(array && array.length)) {
    return [];
  }
  var length = 0;
  array = _arrayFilter.default(array, function(group) {
    if (isArrayLikeObject.default(group)) {
      length = nativeMax(group.length, length);
      return true;
    }
  });
  return _baseTimes.default(length, function(index) {
    return _arrayMap.default(array, _baseProperty.default(index));
  });
}

exports.default = unzip;
//# sourceMappingURL=unzip.js.map
