'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _asciiWords = require('./_asciiWords.js');
var _hasUnicodeWord = require('./_hasUnicodeWord.js');
var toString = require('./toString.js');
var _unicodeWords = require('./_unicodeWords.js');

/**
 * Splits `string` into an array of its words.
 *
 * @static
 * @memberOf _
 * @since 3.0.0
 * @category String
 * @param {string} [string=''] The string to inspect.
 * @param {RegExp|string} [pattern] The pattern to match words.
 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
 * @returns {Array} Returns the words of `string`.
 * @example
 *
 * _.words('fred, barney, & pebbles');
 * // => ['fred', 'barney', 'pebbles']
 *
 * _.words('fred, barney, & pebbles', /[^, ]+/g);
 * // => ['fred', 'barney', '&', 'pebbles']
 */
function words(string, pattern, guard) {
  string = toString.default(string);
  pattern = guard ? undefined : pattern;

  if (pattern === undefined) {
    return _hasUnicodeWord.default(string) ? _unicodeWords.default(string) : _asciiWords.default(string);
  }
  return string.match(pattern) || [];
}

exports.default = words;
//# sourceMappingURL=words.js.map
