'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _LazyWrapper = require('./_LazyWrapper.js');
var _LodashWrapper = require('./_LodashWrapper.js');
var _baseAt = require('./_baseAt.js');
var _flatRest = require('./_flatRest.js');
var _isIndex = require('./_isIndex.js');
var thru = require('./thru.js');

/**
 * This method is the wrapper version of `_.at`.
 *
 * @name at
 * @memberOf _
 * @since 1.0.0
 * @category Seq
 * @param {...(string|string[])} [paths] The property paths to pick.
 * @returns {Object} Returns the new `lodash` wrapper instance.
 * @example
 *
 * var object = { 'a': [{ 'b': { 'c': 3 } }, 4] };
 *
 * _(object).at(['a[0].b.c', 'a[1]']).value();
 * // => [3, 4]
 */
var wrapperAt = _flatRest.default(function(paths) {
  var length = paths.length,
      start = length ? paths[0] : 0,
      value = this.__wrapped__,
      interceptor = function(object) { return _baseAt.default(object, paths); };

  if (length > 1 || this.__actions__.length ||
      !(value instanceof _LazyWrapper.default) || !_isIndex.default(start)) {
    return this.thru(interceptor);
  }
  value = value.slice(start, +start + (length ? 1 : 0));
  value.__actions__.push({
    'func': thru.default,
    'args': [interceptor],
    'thisArg': undefined
  });
  return new _LodashWrapper.default(value, this.__chain__).thru(function(array) {
    if (length && !array.length) {
      array.push(undefined);
    }
    return array;
  });
});

exports.default = wrapperAt;
//# sourceMappingURL=wrapperAt.js.map
