'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayFilter = require('./_arrayFilter.js');
var _baseIteratee = require('./_baseIteratee.js');
var _baseRest = require('./_baseRest.js');
var _baseXor = require('./_baseXor.js');
var isArrayLikeObject = require('./isArrayLikeObject.js');
var last = require('./last.js');

/**
 * This method is like `_.xor` except that it accepts `iteratee` which is
 * invoked for each element of each `arrays` to generate the criterion by
 * which by which they're compared. The order of result values is determined
 * by the order they occur in the arrays. The iteratee is invoked with one
 * argument: (value).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Array
 * @param {...Array} [arrays] The arrays to inspect.
 * @param {Function} [iteratee=_.identity] The iteratee invoked per element.
 * @returns {Array} Returns the new array of filtered values.
 * @example
 *
 * _.xorBy([2.1, 1.2], [2.3, 3.4], Math.floor);
 * // => [1.2, 3.4]
 *
 * // The `_.property` iteratee shorthand.
 * _.xorBy([{ 'x': 1 }], [{ 'x': 2 }, { 'x': 1 }], 'x');
 * // => [{ 'x': 2 }]
 */
var xorBy = _baseRest.default(function(arrays) {
  var iteratee = last.default(arrays);
  if (isArrayLikeObject.default(iteratee)) {
    iteratee = undefined;
  }
  return _baseXor.default(_arrayFilter.default(arrays, isArrayLikeObject.default), _baseIteratee.default(iteratee, 2));
});

exports.default = xorBy;
//# sourceMappingURL=xorBy.js.map
