'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _arrayFilter = require('./_arrayFilter.js');
var _baseRest = require('./_baseRest.js');
var _baseXor = require('./_baseXor.js');
var isArrayLikeObject = require('./isArrayLikeObject.js');
var last = require('./last.js');

/**
 * This method is like `_.xor` except that it accepts `comparator` which is
 * invoked to compare elements of `arrays`. The order of result values is
 * determined by the order they occur in the arrays. The comparator is invoked
 * with two arguments: (arrVal, othVal).
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Array
 * @param {...Array} [arrays] The arrays to inspect.
 * @param {Function} [comparator] The comparator invoked per element.
 * @returns {Array} Returns the new array of filtered values.
 * @example
 *
 * var objects = [{ 'x': 1, 'y': 2 }, { 'x': 2, 'y': 1 }];
 * var others = [{ 'x': 1, 'y': 1 }, { 'x': 1, 'y': 2 }];
 *
 * _.xorWith(objects, others, _.isEqual);
 * // => [{ 'x': 2, 'y': 1 }, { 'x': 1, 'y': 1 }]
 */
var xorWith = _baseRest.default(function(arrays) {
  var comparator = last.default(arrays);
  comparator = typeof comparator == 'function' ? comparator : undefined;
  return _baseXor.default(_arrayFilter.default(arrays, isArrayLikeObject.default), undefined, comparator);
});

exports.default = xorWith;
//# sourceMappingURL=xorWith.js.map
