'use strict';

var Enum = require('./Enum.js');
var Utility = require('./Utility.js');
var Tokenizer = require('./Tokenizer.js');
var Serializer = require('./Serializer.js');
var Prefixer = require('./Prefixer.js');

/**
 * @param {function[]} collection
 * @return {function}
 */
function middleware (collection) {
	var length = Utility.sizeof(collection);

	return function (element, index, children, callback) {
		var output = '';

		for (var i = 0; i < length; i++)
			output += collection[i](element, index, children, callback) || '';

		return output
	}
}

/**
 * @param {function} callback
 * @return {function}
 */
function rulesheet (callback) {
	return function (element) {
		if (!element.root)
			if (element = element.return)
				callback(element);
	}
}

/**
 * @param {object} element
 * @param {number} index
 * @param {object[]} children
 * @param {function} callback
 */
function prefixer (element, index, children, callback) {
	if (element.length > -1)
		if (!element.return)
			switch (element.type) {
				case Enum.DECLARATION: element.return = Prefixer.prefix(element.value, element.length, children);
					return
				case Enum.KEYFRAMES:
					return Serializer.serialize([Tokenizer.copy(element, {value: Utility.replace(element.value, '@', '@' + Enum.WEBKIT)})], callback)
				case Enum.RULESET:
					if (element.length)
						return Utility.combine(element.props, function (value) {
							switch (Utility.match(value, /(::plac\w+|:read-\w+)/)) {
								// :read-(only|write)
								case ':read-only': case ':read-write':
									return Serializer.serialize([Tokenizer.copy(element, {props: [Utility.replace(value, /:(read-\w+)/, ':' + Enum.MOZ + '$1')]})], callback)
								// :placeholder
								case '::placeholder':
									return Serializer.serialize([
										Tokenizer.copy(element, {props: [Utility.replace(value, /:(plac\w+)/, ':' + Enum.WEBKIT + 'input-$1')]}),
										Tokenizer.copy(element, {props: [Utility.replace(value, /:(plac\w+)/, ':' + Enum.MOZ + '$1')]}),
										Tokenizer.copy(element, {props: [Utility.replace(value, /:(plac\w+)/, Enum.MS + 'input-$1')]})
									], callback)
							}

							return ''
						})
			}
}

/**
 * @param {object} element
 * @param {number} index
 * @param {object[]} children
 */
function namespace (element) {
	switch (element.type) {
		case Enum.RULESET:
			element.props = element.props.map(function (value) {
				return Utility.combine(Tokenizer.tokenize(value), function (value, index, children) {
					switch (Utility.charat(value, 0)) {
						// \f
						case 12:
							return Utility.substr(value, 1, Utility.strlen(value))
						// \0 ( + > ~
						case 0: case 40: case 43: case 62: case 126:
							return value
						// :
						case 58:
							if (children[++index] === 'global')
								children[index] = '', children[++index] = '\f' + Utility.substr(children[index], index = 1, -1);
						// \s
						case 32:
							return index === 1 ? '' : value
						default:
							switch (index) {
								case 0: element = value;
									return Utility.sizeof(children) > 1 ? '' : value
								case index = Utility.sizeof(children) - 1: case 2:
									return index === 2 ? value + element + element : value + element
								default:
									return value
							}
					}
				})
			});
	}
}

exports.middleware = middleware;
exports.namespace = namespace;
exports.prefixer = prefixer;
exports.rulesheet = rulesheet;
//# sourceMappingURL=Middleware.js.map
