'use strict';

var Enum = require('./Enum.js');
var Utility = require('./Utility.js');

/**
 * @param {string} value
 * @param {number} length
 * @param {object[]} children
 * @return {string}
 */
function prefix (value, length, children) {
	switch (Utility.hash(value, length)) {
		// color-adjust
		case 5103:
			return Enum.WEBKIT + 'print-' + value + value
		// animation, animation-(delay|direction|duration|fill-mode|iteration-count|name|play-state|timing-function)
		case 5737: case 4201: case 3177: case 3433: case 1641: case 4457: case 2921:
		// text-decoration, filter, clip-path, backface-visibility, column, box-decoration-break
		case 5572: case 6356: case 5844: case 3191: case 6645: case 3005:
		// mask, mask-image, mask-(mode|clip|size), mask-(repeat|origin), mask-position, mask-composite,
		case 6391: case 5879: case 5623: case 6135: case 4599: case 4855:
		// background-clip, columns, column-(count|fill|gap|rule|rule-color|rule-style|rule-width|span|width)
		case 4215: case 6389: case 5109: case 5365: case 5621: case 3829:
			return Enum.WEBKIT + value + value
		// tab-size
		case 4789:
			return Enum.MOZ + value + value
		// appearance, user-select, transform, hyphens, text-size-adjust
		case 5349: case 4246: case 4810: case 6968: case 2756:
			return Enum.WEBKIT + value + Enum.MOZ + value + Enum.MS + value + value
		// writing-mode
		case 5936:
			switch (Utility.charat(value, length + 11)) {
				// vertical-l(r)
				case 114:
					return Enum.WEBKIT + value + Enum.MS + Utility.replace(value, /[svh]\w+-[tblr]{2}/, 'tb') + value
				// vertical-r(l)
				case 108:
					return Enum.WEBKIT + value + Enum.MS + Utility.replace(value, /[svh]\w+-[tblr]{2}/, 'tb-rl') + value
				// horizontal(-)tb
				case 45:
					return Enum.WEBKIT + value + Enum.MS + Utility.replace(value, /[svh]\w+-[tblr]{2}/, 'lr') + value
				// default: fallthrough to below
			}
		// flex, flex-direction, scroll-snap-type, writing-mode
		case 6828: case 4268: case 2903:
			return Enum.WEBKIT + value + Enum.MS + value + value
		// order
		case 6165:
			return Enum.WEBKIT + value + Enum.MS + 'flex-' + value + value
		// align-items
		case 5187:
			return Enum.WEBKIT + value + Utility.replace(value, /(\w+).+(:[^]+)/, Enum.WEBKIT + 'box-$1$2' + Enum.MS + 'flex-$1$2') + value
		// align-self
		case 5443:
			return Enum.WEBKIT + value + Enum.MS + 'flex-item-' + Utility.replace(value, /flex-|-self/g, '') + (!Utility.match(value, /flex-|baseline/) ? Enum.MS + 'grid-row-' + Utility.replace(value, /flex-|-self/g, '') : '') + value
		// align-content
		case 4675:
			return Enum.WEBKIT + value + Enum.MS + 'flex-line-pack' + Utility.replace(value, /align-content|flex-|-self/g, '') + value
		// flex-shrink
		case 5548:
			return Enum.WEBKIT + value + Enum.MS + Utility.replace(value, 'shrink', 'negative') + value
		// flex-basis
		case 5292:
			return Enum.WEBKIT + value + Enum.MS + Utility.replace(value, 'basis', 'preferred-size') + value
		// flex-grow
		case 6060:
			return Enum.WEBKIT + 'box-' + Utility.replace(value, '-grow', '') + Enum.WEBKIT + value + Enum.MS + Utility.replace(value, 'grow', 'positive') + value
		// transition
		case 4554:
			return Enum.WEBKIT + Utility.replace(value, /([^-])(transform)/g, '$1' + Enum.WEBKIT + '$2') + value
		// cursor
		case 6187:
			return Utility.replace(Utility.replace(Utility.replace(value, /(zoom-|grab)/, Enum.WEBKIT + '$1'), /(image-set)/, Enum.WEBKIT + '$1'), value, '') + value
		// background, background-image
		case 5495: case 3959:
			return Utility.replace(value, /(image-set\([^]*)/, Enum.WEBKIT + '$1' + '$`$1')
		// justify-content
		case 4968:
			return Utility.replace(Utility.replace(value, /(.+:)(flex-)?(.*)/, Enum.WEBKIT + 'box-pack:$3' + Enum.MS + 'flex-pack:$3'), /s.+-b[^;]+/, 'justify') + Enum.WEBKIT + value + value
		// justify-self
		case 4200:
			if (!Utility.match(value, /flex-|baseline/)) return Enum.MS + 'grid-column-align' + Utility.substr(value, length) + value
			break
		// grid-template-(columns|rows)
		case 2592: case 3360:
			return Enum.MS + Utility.replace(value, 'template-', '') + value
		// grid-(row|column)-start
		case 4384: case 3616:
			if (children && children.some(function (element, index) { return length = index, Utility.match(element.props, /grid-\w+-end/) })) {
				return ~Utility.indexof(value + (children = children[length].value), 'span') ? value : (Enum.MS + Utility.replace(value, '-start', '') + value + Enum.MS + 'grid-row-span:' + (~Utility.indexof(children, 'span') ? Utility.match(children, /\d+/) : +Utility.match(children, /\d+/) - +Utility.match(value, /\d+/)) + ';')
			}
			return Enum.MS + Utility.replace(value, '-start', '') + value
		// grid-(row|column)-end
		case 4896: case 4128:
			return (children && children.some(function (element) { return Utility.match(element.props, /grid-\w+-start/) })) ? value : Enum.MS + Utility.replace(Utility.replace(value, '-end', '-span'), 'span ', '') + value
		// (margin|padding)-inline-(start|end)
		case 4095: case 3583: case 4068: case 2532:
			return Utility.replace(value, /(.+)-inline(.+)/, Enum.WEBKIT + '$1$2') + value
		// (min|max)?(width|height|inline-size|block-size)
		case 8116: case 7059: case 5753: case 5535:
		case 5445: case 5701: case 4933: case 4677:
		case 5533: case 5789: case 5021: case 4765:
			// stretch, max-content, min-content, fill-available
			if (Utility.strlen(value) - 1 - length > 6)
				switch (Utility.charat(value, length + 1)) {
					// (m)ax-content, (m)in-content
					case 109:
						// -
						if (Utility.charat(value, length + 4) !== 45)
							break
					// (f)ill-available, (f)it-content
					case 102:
						return Utility.replace(value, /(.+:)(.+)-([^]+)/, '$1' + Enum.WEBKIT + '$2-$3' + '$1' + Enum.MOZ + (Utility.charat(value, length + 3) == 108 ? '$3' : '$2-$3')) + value
					// (s)tretch
					case 115:
						return ~Utility.indexof(value, 'stretch') ? prefix(Utility.replace(value, 'stretch', 'fill-available'), length, children) + value : value
				}
			break
		// grid-(column|row)
		case 5152: case 5920:
			return Utility.replace(value, /(.+?):(\d+)(\s*\/\s*(span)?\s*(\d+))?(.*)/, function (_, a, b, c, d, e, f) { return (Enum.MS + a + ':' + b + f) + (c ? (Enum.MS + a + '-span:' + (d ? e : +e - +b)) + f : '') + value })
		// position: sticky
		case 4949:
			// stick(y)?
			if (Utility.charat(value, length + 6) === 121)
				return Utility.replace(value, ':', ':' + Enum.WEBKIT) + value
			break
		// display: (flex|inline-flex|grid|inline-grid)
		case 6444:
			switch (Utility.charat(value, Utility.charat(value, 14) === 45 ? 18 : 11)) {
				// (inline-)?fle(x)
				case 120:
					return Utility.replace(value, /(.+:)([^;\s!]+)(;|(\s+)?!.+)?/, '$1' + Enum.WEBKIT + (Utility.charat(value, 14) === 45 ? 'inline-' : '') + 'box$3' + '$1' + Enum.WEBKIT + '$2$3' + '$1' + Enum.MS + '$2box$3') + value
				// (inline-)?gri(d)
				case 100:
					return Utility.replace(value, ':', ':' + Enum.MS) + value
			}
			break
		// scroll-margin, scroll-margin-(top|right|bottom|left)
		case 5719: case 2647: case 2135: case 3927: case 2391:
			return Utility.replace(value, 'scroll-', 'scroll-snap-') + value
	}

	return value
}

exports.prefix = prefix;
//# sourceMappingURL=Prefixer.js.map
