'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../core/index.js');
var utils = require('../core/utils.js');
require('../hooks/index.js');
var useTheme = require('../hooks/use-theme.js');
var theme = require('../core/theme.js');
var useThemeProvider = require('../hooks/use-theme-provider.js');

"use strict";
var ThemeProvider = /* @__PURE__ */ vue.defineComponent({
  name: "ThemeProvider",
  props: {
    theme: {
      type: Object,
      required: true
    },
    component: {
      type: [String, Object],
      default: "div"
    },
    watcher: {
      type: Function
    }
  },
  emits: ["update:theme"],
  setup(props, {
    slots,
    emit
  }) {
    const html = document.documentElement;
    const theme$1 = vue.ref(props.theme);
    const parentTheme = props.theme.target === "host" ? useTheme.useTheme() : vue.ref(null);
    const element = vue.ref(null);
    const lightSchemes = theme$1.value._lightSchemes;
    const darkSchemes = theme$1.value._darkSchemes;
    const injectCss = utils.injectJSS(theme$1.value.target, lightSchemes, darkSchemes, theme$1.value);
    const toggleTheme = (mode) => {
      const dom = props.theme.target === "root" ? html : element.value;
      const {
        schemes
      } = mode === "dark" ? darkSchemes : lightSchemes;
      if (mode === "dark") {
        dom.setAttribute("data-theme", "dark");
      } else {
        dom.removeAttribute("data-theme");
      }
      const {
        palettes,
        target,
        schemes: $schemes
      } = theme$1.value;
      theme$1.value = new theme.default({
        ...$schemes,
        ...schemes
      }, palettes, mode, lightSchemes, darkSchemes, target);
      emit("update:theme", theme$1.value);
    };
    const watchTarget = props.theme.target === "root" ? () => props.theme.mode : () => parentTheme.value?.mode ?? props.theme.mode;
    props.watcher ? props.watcher() : vue.watch(watchTarget, toggleTheme);
    useThemeProvider.useThemeProvider(theme$1);
    const Comp = props.component;
    return () => (
      // eslint-disable-next-line multiline-ternary
      theme$1.value.target === "root" ? slots.default?.() : vue.createVNode(Comp, {
        "ref": element,
        "class": injectCss
      }, {
        default: () => [slots.default?.()]
      })
    );
  }
});

exports.default = ThemeProvider;
//# sourceMappingURL=theme-provider.js.map
