'use strict';

var emotionCss_esm = require('../../../node_modules/.pnpm/@emotion_css@11.11.2/node_modules/@emotion/css/dist/emotion-css.esm.js');
require('../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/index.js');
var string_utils = require('../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/utils/string_utils.js');
var core_palette = require('../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/palettes/core_palette.js');
var color_utils = require('../../../node_modules/.pnpm/@material_material-color-utilities@0.2.7/node_modules/@material/material-color-utilities/utils/color_utils.js');

"use strict";
const themePalettesTones = [
  "0",
  "10",
  "20",
  "30",
  "40",
  "50",
  "60",
  "70",
  "80",
  "90",
  "95",
  "99",
  "100"
];
const parsePalettes = (palette) => {
  const palettes = {};
  for (const [color, tones] of Object.entries(palette)) {
    const obj = {};
    themePalettesTones.forEach(
      (toneKey) => obj[toneKey] = string_utils.hexFromArgb(tones.tone(+toneKey))
    );
    palettes[color] = obj;
  }
  return palettes;
};
const createCustomPalettes = (customColors) => {
  const palettes = {};
  customColors.forEach((color) => {
    const { name, value } = color;
    const tones = core_palette.CorePalette.of(value).a1;
    const obj = {};
    themePalettesTones.forEach(
      (toneKey) => obj[toneKey] = string_utils.hexFromArgb(tones.tone(+toneKey))
    );
    palettes[name.toLowerCase()] = obj;
  });
  return palettes;
};
const parseShcemes = (scheme) => {
  const schemes = {};
  const styles = {};
  for (const [key, value] of Object.entries(scheme.toJSON())) {
    const token = key.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
    const color = string_utils.hexFromArgb(value);
    const { r, g, b } = color_utils.rgbaFromArgb(value);
    schemes[key] = color;
    styles[`--md-sys-color-${token}`] = color;
    styles[`--md-sys-color-${token}-rgb`] = `${r} ${g} ${b}`;
  }
  return { schemes, styles };
};
const parseCustomSchemes = (scheme, mode) => {
  const schemes = {};
  const styles = {};
  scheme.forEach((scheme2) => {
    const { name } = scheme2.color;
    const _palette = mode === "light" ? scheme2.light : scheme2.dark;
    for (const [key, value] of Object.entries(_palette)) {
      const _key = key.startsWith("on") ? key.replace("Color", `${name[0].toUpperCase()}${name.slice(1)}`) : key.replace("color", name);
      const token = _key.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
      const color = string_utils.hexFromArgb(value);
      const { r, g, b } = color_utils.rgbaFromArgb(value);
      schemes[_key] = color;
      styles[`--md-sys-color-${token}`] = color;
      styles[`--md-sys-color-${token}-rgb`] = `${r} ${g} ${b}`;
    }
  });
  return { schemes, styles };
};
const mergeParsedSchemes = (...args) => {
  const schemes = {};
  const styles = {};
  args.forEach((parsedScheme) => {
    Object.assign(schemes, parsedScheme.schemes);
    Object.assign(styles, parsedScheme.styles);
  });
  return { schemes, styles };
};
const injectJSS = (target, lightSchemes, darkSchemes, theme) => {
  const { fontFamily, htmlFontSize } = theme.typography;
  let injectCss;
  if (target === "root") {
    emotionCss_esm.injectGlobal({
      ":root": {
        colorScheme: "light",
        ...lightSchemes?.styles
      },
      ':root[data-theme="dark"]': {
        colorScheme: "dark",
        ...darkSchemes?.styles
      },
      html: {
        fontSize: htmlFontSize
      },
      body: {
        fontFamily,
        color: "var(--md-sys-color-on-surface)",
        fontSize: "1rem"
      }
    });
  } else {
    injectCss = emotionCss_esm.css({
      ...lightSchemes?.styles,
      '&[data-theme="dark"]': {
        ...darkSchemes?.styles
      }
    });
  }
  return injectCss;
};
const newSchemes = (dynamicTheme) => {
  const {
    palettes: { neutral, neutralVariant }
  } = dynamicTheme;
  return {
    light: {
      surfaceDim: neutral.tone(87),
      surface: neutral.tone(98),
      surfaceBright: neutral.tone(98),
      surfaceContainerLowest: neutral.tone(100),
      surfaceContainerLow: neutral.tone(96),
      surfaceContainer: neutral.tone(94),
      surfaceContainerHigh: neutral.tone(92),
      surfaceContainerHighest: neutral.tone(90),
      onSurface: neutral.tone(10),
      onSurfaceVariant: neutralVariant.tone(30),
      outline: neutralVariant.tone(50),
      outlineVariant: neutralVariant.tone(80)
    },
    dark: {
      surfaceDim: neutral.tone(6),
      surface: neutral.tone(6),
      surfaceBright: neutral.tone(24),
      surfaceContainerLowest: neutral.tone(4),
      surfaceContainerLow: neutral.tone(10),
      surfaceContainer: neutral.tone(12),
      surfaceContainerHigh: neutral.tone(17),
      surfaceContainerHighest: neutral.tone(22),
      onSurface: neutral.tone(90),
      onSurfaceVariant: neutralVariant.tone(80),
      outline: neutralVariant.tone(60),
      outlineVariant: neutralVariant.tone(30)
    }
  };
};
const parsedNewSchemes = (scheme) => {
  const schemes = {};
  const styles = {};
  for (const [key, value] of Object.entries(scheme)) {
    const token = key.replace(/([a-z])([A-Z])/g, "$1-$2").toLowerCase();
    const color = string_utils.hexFromArgb(value);
    const { r, g, b } = color_utils.rgbaFromArgb(value);
    schemes[key] = color;
    styles[`--md-sys-color-${token}`] = color;
    styles[`--md-sys-color-${token}-rgb`] = `${r} ${g} ${b}`;
  }
  return { schemes, styles };
};

exports.createCustomPalettes = createCustomPalettes;
exports.injectJSS = injectJSS;
exports.mergeParsedSchemes = mergeParsedSchemes;
exports.newSchemes = newSchemes;
exports.parseCustomSchemes = parseCustomSchemes;
exports.parsePalettes = parsePalettes;
exports.parseShcemes = parseShcemes;
exports.parsedNewSchemes = parsedNewSchemes;
//# sourceMappingURL=utils.js.map
