import type { CustomColor, CustomColorGroup, Theme as DynamicTheme, Scheme } from '@material/material-color-utilities';
import type { ThemeMode } from '../mode';
import type { ThemePalettes } from '../types';
import type { ParsedSchemes } from './types';
import type Theme from './theme';
export declare const parsePalettes: (palette: DynamicTheme['palettes']) => ThemePalettes;
export declare const createCustomPalettes: (customColors: CustomColor[]) => any;
export declare const parseShcemes: (scheme: Scheme) => ParsedSchemes;
export declare const parseCustomSchemes: (scheme: CustomColorGroup[], mode: ThemeMode) => ParsedSchemes;
/**
 * Merge the parsed schemes into one object
 * @param {ParsedSchemes[]} args The parsed schemes
 * @returns {ParsedSchemes} The merged parsed schemes
 */
export declare const mergeParsedSchemes: (...args: ParsedSchemes[]) => ParsedSchemes;
/**
 * Inject the schemes to the target element
 * @param {'root' | 'host'} target The target element to inject the schemes
 * root: the root element (html) of the document
 * host: the current element (the theme provider component)
 * @param {ParsedSchemes} lightSchemes The light schemes
 * @param {ParsedSchemes} darkSchemes The dark schemes
 * @param {Theme} theme The theme object
 */
export declare const injectJSS: (target: 'root' | 'host', lightSchemes: ParsedSchemes, darkSchemes: ParsedSchemes, theme: Theme) => string | undefined;
export interface NewSchemes {
    surfaceDim: number;
    surface: number;
    surfaceBright: number;
    surfaceContainerLowest: number;
    surfaceContainerLow: number;
    surfaceContainer: number;
    surfaceContainerHigh: number;
    surfaceContainerHighest: number;
    onSurface: number;
    onSurfaceVariant: number;
    outline: number;
    outlineVariant: number;
}
export interface AdditionalThemeSchemes {
    light: NewSchemes;
    dark: NewSchemes;
}
export interface ParsedNewSchemes {
    schemes: Record<keyof NewSchemes, string>;
    styles: Record<string, string>;
}
/**
 * The hrlper function to create the new scheme according to latest version Material Design Color System
 * expecially the "Surface" series
 * @link https://m3.material.io/styles/color/static/baseline#690f18cd-d40f-4158-a358-4cfdb3a32768
 * @param {DynamicTheme} dynamicTheme The dynamic theme object
 */
export declare const newSchemes: (dynamicTheme: DynamicTheme) => AdditionalThemeSchemes;
export declare const parsedNewSchemes: (scheme: NewSchemes) => ParsedNewSchemes;
