import type { ComputedRef, Ref } from 'vue';
import type { Rgba } from '@material/material-color-utilities';
/**
 * The function converts hex color to rgba color
 * @param {string} hex The hex color
 * @return {Rgba} The rgba color obj
 */
export declare const rgbaFromHex: (hex: string) => Rgba;
/**
 * The function to compute color from props
 * The props.color can be "primary" | "secondary" | "tertiary" | "error" | (theme: Theme) => string | "string"
 * Use this function to get the final color value
 * @param {T extends { [k: string]: AcceptableColor | any }} props The props of component
 * @param {keyof T | undefined | null} key The key of props
 * Set the key to null or undefined to use default color
 * @return Return the computed string. The value can be CSS variable or color in hex
 */
export declare const useRgbColor: <T extends {
    [k: string]: any;
}>(props: T, key: keyof T | null | undefined) => Ref<null>[] | ComputedRef<string>[];
