import type { PropType } from 'vue';
import type { IfInProp, IfNativePropType, InProp, InPropConvert, InPropFinalized, InPropInput, InPropMergeType, NativePropType } from './types';
export declare const inPropKey = "__epPropKey";
export declare const definePropType: <T>(val: any) => PropType<T>;
export declare const isEpProp: (val: unknown) => val is InProp<any, any, any>;
/**
 * @description Build prop. It can better optimize prop types
 * @description 生成 prop，能更好地优化类型
 * @example
  // limited options
  // the type will be PropType<'light' | 'dark'>
  buildProp({
    type: String,
    values: ['light', 'dark'],
  } as const)
  * @example
  // limited options and other types
  // the type will be PropType<'small' | 'large' | number>
  buildProp({
    type: [String, Number],
    values: ['small', 'large'],
    validator: (val: unknown): val is number => typeof val === 'number',
  } as const)
  @link see more: https://github.com/element-plus/element-plus/pull/3341
 */
export declare const buildProp: <Type = never, Value = never, Validator = never, Default extends InPropMergeType<Type, Value, Validator> = never, Required_1 extends boolean = false>(prop: InPropInput<Type, Value, Validator, Default, Required_1>, key?: string) => InPropFinalized<Type, Value, Validator, Default, Required_1>;
export declare const buildProps: <Props extends Record<string, NativePropType | {
    __epPropKey: true;
} | InPropInput<any, any, any, any, any>>>(props: Props) => { [K in keyof Props]: IfInProp<Props[K], Props[K], IfNativePropType<Props[K], Props[K], InPropConvert<Props[K]>>>; };
